@@ -10,20 +10,17 @@ module IExtract
   ) where
 
 import List
-import TokenId(TokenId(..),t_Arrow,t_Tuple,ensureM,dropM,forceM,rpsPrelude
+import TokenId(TokenId(..),t_Arrow,ensureM,dropM,forceM
 		,tEq,tOrd,tBounded,tRead,tShow,visible,tUnknown,tunknown)
 import State
 import IdKind
-import Syntax
 import Extra
-import NeedLib
 import AssocTree
 import Memo
-import PackedString(PackedString,packString,unpackPS)
+import SysDeps(PackedString)
 import NT
-import Syntax
-import OsOnly(isPrelude)
-import ImportState
+import Syntax hiding (TokenId)
+import ImportState hiding (TokenId)
 import Id(Id)
 
 --import PrettyLib	-- debugging output only
@@ -61,11 +58,6 @@ fixOne rps (fixClass,level,ids) fixity_err =
   let fl = (fixClass,level)
   in foldr  (fixAdd fl) fixity_err (map (fixTid rps) ids)
 
-changeType Infix = Infix
-changeType InfixDef = InfixDef
-changeType InfixL = InfixL
-changeType InfixR = InfixR
-
 fixTid rps (FixCon _ tid) = ensureM rps tid
 fixTid rps (FixVar _ tid) = ensureM rps tid
 
@@ -224,7 +216,7 @@ importField q free ctxs bt c ((Just (p,tid,_),nt),i) down
               (addAT -- add field name
                 (addAT st combInfo (realtid,Var) -- add selector
 		  (InfoVar  unique realtid IEnone (fixity realtid)
-                    (NewType free [] ctxs [NTcons bt (map NTvar free),nt]) 
+                    (NewType free [] ctxs [mkNTcons bt (map mkNTvar free),nt]) 
                     (Just 1)))
 		combInfo key (InfoField u realtid IEnone [(c,i)] bt unique)) 
               insts fixity errors)
@@ -245,7 +237,7 @@ importField q free ctxs bt c ((Just (p,tid,_),nt),i) down
 	      (addAT -- add field name
                 (addAT st combInfo (realtid,Var) -- add selector
 		  (InfoVar  (unique+1) realtid IEnone (fixity realtid)
-                    (NewType free [] ctxs [NTcons bt (map NTvar free),nt]) 
+                    (NewType free [] ctxs [mkNTcons bt (map mkNTvar free),nt]) 
                     (Just 1)))
 		combInfo key (InfoField unique realtid IEnone [(c,i)]
                                         bt (unique+1)))
@@ -463,7 +455,7 @@ iextractType expInfo (depth,unboxed) q pos tid tvs typ =
 -- the information about the data type comes from an interface file
 -}
 iextractData :: IE -> (TokenId->Bool) -> Either Bool Bool -> [Context TokenId] 
-             -> Int -> TokenId -> [(Pos,TokenId)] -> [Constr TokenId] 
+             -> Pos -> TokenId -> [(Pos,TokenId)] -> [Constr TokenId] 
              -> [TokenId] -> () -> ImportState -> ImportState
 
 iextractData  expInfo q attr ctxs pos tid tvs constrs needs =
@@ -473,7 +465,11 @@ iextractData  expInfo q attr ctxs pos tid tvs constrs needs =
                               ++ [TypeCons pos tid (map (uncurry TypeVar) tvs)])
      >>>= \nt@(NewType free [] ctxs nts) ->
      mapS (transConstr q al free ctxs needs (last nts)) constrs >>>= \cs ->
-     importData q tid expInfo nt 
+     importData q tid -- expInfo nt 
+       ((case attr of
+           Left _ -> patchIE
+           _      -> id) expInfo)
+       nt
        (case attr of
 	  Right unboxed -> Data unboxed cs
 	  Left  unboxed -> DataNewType unboxed cs) >>>
@@ -481,18 +477,18 @@ iextractData  expInfo q attr ctxs pos tid tvs constrs needs =
      mapS0 newInstance newinsts
 
 
-iextractDataPrim :: IE -> (TokenId->Bool) -> Int -> TokenId -> Int 
+iextractDataPrim :: IE -> (TokenId->Bool) -> Pos -> TokenId -> Int 
                  -> a -> ImportState -> ImportState
 
 iextractDataPrim expInfo q pos tid size =
      transTid pos TCon tid >>>= \ i ->
-     importData q tid expInfo (NewType [] [] [] [NTcons i []])
+     importData q tid expInfo (NewType [] [] [] [mkNTcons i []])
                               (DataPrimitive size) >>>
      checkInstanceCon tid >>>= \ newinsts ->
      mapS0 newInstance newinsts
 
 
-iextractClass :: IE -> (TokenId->Bool) -> Int -> [Context TokenId] 
+iextractClass :: IE -> (TokenId->Bool) -> Pos -> [Context TokenId] 
               -> TokenId -> TokenId 
               -> [([((a,TokenId),b)],[Context TokenId],Type TokenId)] 
               -> [TokenId] -> () -> ImportState -> ImportState
@@ -508,7 +504,7 @@ iextractClass  expInfo q pos ctxs tid tvar methods needs =
      mapS0 newInstance newinsts
 
 
-newInstance :: (TokenId,TokenId,[Int],[(Int,TokenId,Int)]) 
+newInstance :: (TokenId,TokenId,[Int],[(Pos,TokenId,Int)]) 
             -> a -> ImportState -> ImportState
 
 newInstance (realcls,realcon,free,ctxs) =
@@ -522,7 +518,10 @@ newInstance (realcls,realcon,free,ctxs) =
 iextractInstance :: [Context TokenId] -> a -> TokenId -> Type TokenId 
                  -> () -> ImportState -> ImportState
 
-iextractInstance ctxs pos cls typ@(TypeCons _ con _) =
+-- iextractInstance ctxs pos cls typ@(TypeCons _ con _) =
+iextractInstance ctxs pos cls typ =
+  let con = case typ of (TypeCons _ con _) -> con; (TypeVar _ con) -> con
+  in
   existTid TClass cls >>>= \qcls ->
   existTid TCon con >>>= \qcon ->
   let al = tvTids (snub (freeType typ))
@@ -531,8 +530,8 @@ iextractInstance ctxs pos cls typ@(TypeCons _ con _) =
                        -- then add the instance to the type class
     then
       transTypes al (map snd al) ctxs [typ]
-      >>>= \(NewType free [] ctxs [NTcons c nts]) ->
-      importInstance cls c free {- (map ( \ (NTvar v) -> v) nts) -} ctxs
+      >>>= \(NewType free [] ctxs [NTcons c _ nts]) ->
+      importInstance cls c free {- (map ( \ (NTvar v _) -> v) nts) -} ctxs
     else
       storeInstance al cls con ctxs -- otherwise save the instance for later
 
@@ -595,7 +594,7 @@ transConstr :: (TokenId->Bool) -> [(TokenId,Int)] -> [Int] -> [(Id,Id)]
             -> [TokenId] -> NT -> Constr TokenId 
             -> () -> ImportState -> (Int,ImportState)
 
-transConstr q al free ctxs needed resType@(NTcons bt _) (Constr pos cid types) =
+transConstr q al free ctxs needed resType@(NTcons bt _ _) (Constr pos cid types) =
   mapS (transFieldType al) types >>>= \ntss ->
   let all = concat ntss
       nts = map snd all
@@ -608,9 +607,9 @@ transConstr q al free ctxs needed resType@(NTcons bt _) (Constr pos cid types) =
   >>>= \c->
   mapS0 (importField q free ctxs bt c) (zip all [ 1:: Int ..]) >>>
   unitS c
-transConstr q al free ctxs needed resType@(NTcons bt _) 
+transConstr q al free ctxs needed resType@(NTcons bt _ _) 
                                   (ConstrCtx forall ectxs' pos cid types) = 
-  let ce = map ( \( Context _ _ [(_,v)]) -> v) ectxs'
+  let -- ce = map ( \( Context _ _ [(_,v)]) -> v) ectxs'
       e =  map snd forall 
 -- filter (`notElem` (map fst al)) $ snub $ (ce ++) $ concat
 --                                                $ map (freeType . snd) types
@@ -635,9 +634,9 @@ transConstr q al free ctxs needed resType@(NTcons bt _)
 
 ---
 
-transFieldType :: [(TokenId,Int)] -> (Maybe [(Int,TokenId)],Type TokenId) 
+transFieldType :: [(TokenId,Int)] -> (Maybe [(Pos,TokenId)],Type TokenId) 
                -> () -> ImportState 
-               -> ([(Maybe (Int,TokenId,Int),NT)],ImportState)
+               -> ([(Maybe (Pos,TokenId,Int),NT)],ImportState)
 
 transFieldType al (Nothing,typ) =
   transType al typ >>>= \ typ -> unitS [(Nothing,typ)]
@@ -660,17 +659,17 @@ transTypes al free ctxs ts =
 {- transform a syntactic type variable (TokenId) into an internal type variable
 -- (NT), using the given mapping
 -}
-transTVar :: Pos -> [(TokenId,Pos)] -> TokenId 
+transTVar :: Pos -> [(TokenId,Id)] -> TokenId 
           -> () -> ImportState -> (NT,ImportState)
 
 transTVar pos al v =
-  unitS NTvar =>>> uniqueTVar pos al v
+  unitS mkNTvar =>>> uniqueTVar pos al v	-- no KIND inference?
 
 
 {- transform syntactic type variable (TokenId) into internal type variable
 -- (Id), using the given mapping
 -}
-uniqueTVar :: Pos -> [(TokenId,Pos)] -> TokenId 
+uniqueTVar :: Pos -> [(TokenId,Id)] -> TokenId 
            -> () -> ImportState -> (Id,ImportState)
 
 uniqueTVar pos al v =
@@ -682,7 +681,7 @@ uniqueTVar pos al v =
 
 
 {- transform syntactic context into internal context -}
-transContext :: [(TokenId,Pos)] -> Context TokenId 
+transContext :: [(TokenId,Id)] -> Context TokenId 
              -> () -> ImportState -> ((Id,Id),ImportState)
 transContext al (Context pos cid [(vpos,vid)]) = 
   unitS pair =>>> transTid pos TClass cid =>>> uniqueTVar vpos al vid
@@ -697,13 +696,13 @@ countArrows _ = 0::Int
 
 
 {- transform a syntactic type into an internal NT type -}
-transType :: [(TokenId,Int)] -> Type TokenId 
+transType :: [(TokenId,Id)] -> Type TokenId 
           -> () -> ImportState -> (NT,ImportState)
 
 transType free (TypeApp  t1 t2) = 
   unitS NTapp =>>> transType free t1 =>>> transType free t2
 transType free (TypeCons  pos hs types) = 
-  unitS NTcons =>>> transTid pos TCon hs =>>> mapS (transType free) types
+  unitS mkNTcons =>>> transTid pos TCon hs =>>> mapS (transType free) types
 transType free (TypeVar   pos v)    = transTVar pos free v
 transType free (TypeStrict pos typ) = unitS NTstrict =>>>  transType free typ
 
