@@ -9,60 +9,44 @@ module Main where
 
 import IO
 import System
-import Monad(when)
 
-import Scc
 import Error
 
 import AssocTree
 import Memo
-import Syntax
+import Syntax hiding (TokenId)
 import PosCode
 
-import OsOnly
-import Extra(Pos(..),mix,mixSpace,jRight,jLeft,noPos,strPos,showErr,mixLine,
-             pair,fst3,thd3,trace)
-import State(State0(..))
-import ImportState(ImportState,Info,IE,initIS,getSymbolTableIS,getErrIS
+import Extra(mixSpace,strPos,showErr,mixLine,thd3)
+import ImportState(ImportState,initIS,getSymbolTableIS,getErrIS
                   ,getRenameTableIS)
-import IntState(IntState,dummyIntState,getSymbolTable,getErrorsIS,strIS,mrpsIS)
-import NeedLib(initNeed)
-import RenameLib(getSymbolTableRS,RenameState,getErrorsRS)
-import ParseCore(Parser(..),ParseBad(..),ParseError(..),ParseGood(..),
-                 ParseResult(..),parseit)
+import IntState(IntState,getSymbolTable,getErrorsIS,strIS,mrpsIS)
+import ParseCore(parseit)
 
 import Flags(Flags,processArgs,pF
-            ,sRealFile,sProfile,sUnix,sUnlit,sSourceFile,sUnderscore,sLex
-            ,sDbgPrelude,sDbgTrans,sNeed,sParse,sIRename,sIBound,sINeed
-            ,sIIBound,sIINeed,sRBound,sRename,sTraceData,sDBound,sDerive
+            ,sRealFile,sProfile,sUnlit,sSourceFile,sUnderscore,sLex
+            ,sNeed,sParse,sIRename,sIBound,sINeed
+            ,sIIBound,sIINeed,sRBound,sRename,sDBound,sDerive
             ,sEBound,sIIRename
-            ,sTraceFns,sRemove,sScc,sRImport,sTBound,sType,sTypeFile,sPrelude
+            ,sRemove,sScc,sRImport,sTBound,sType,sTypeFile,sPrelude
             ,sFSBound,sFixSyntax,sCBound,sCase,sKeepCase,sPBound,sPrim,sFree
             ,sArity,sLBound,sLift,sABound,sAtom,sAnsiC,sObjectFile
             ,sGcode,sGcodeFix,sGcodeOpt1,sGcodeMem,sGcodeOpt2,sGcodeRel)
-import SyntaxPos	-- DW
-import PrettySyntax(prettyPrintTokenId,prettyPrintId -- ,prettyPrintTraceId
+import PrettySyntax(prettyPrintTokenId,prettyPrintId
                    ,ppModule,ppTopDecls,ppClassCodes)
 import StrPos(strPCode)
 
-import TokenId(TokenId(..),t_Arrow,t_List,tPrelude,tminus,tnegate,tTrue)
-import IdKind(IdKind(..))
+import TokenId(TokenId(..))
 import Id(Id)
-import Lex(Lex,LexAnnot)  -- need show
 
 import Unlit(unlit)
-import Lexical(PosToken(..),PosTokenPre(..),LexState(..),lexical)
+import Lexical(lexical)
 import Parse(parseProg)
 import Need(needProg)
-import Overlap(Overlap,Resolution)
 import Import(HideDeclIds,importOne)
 import IExtract(getNeedIS,addPreludeTupleInstances)
 import Rename(rename)
 import FFITrans(ffiTrans)
-import DbgDataTrans(dbgDataTrans)
-import DbgTrans(SRIDTable,debugTrans,dbgAddImport)
-import DbgDumpSRIDTable(dbgDumpSRIDTable)
-import DbgDumpSRIDTableC(dbgDumpSRIDTableC)
 import EmitState
 import Derive(derive)
 import Extract(extract)
@@ -91,13 +75,10 @@ import GcodeLow(gcodeHeader,gcodeDump)
 import GcodeLowC(gcodeCHeader,gcodeGather)
 import GcodeSpec(gcodeZCon)
 import Depend(depend)
-import PackedString(PackedString, unpackPS)
+import SysDeps(PackedString, unpackPS)
 
-import Foreign(Foreign,strForeign)
+import ForeignCode(Foreign,strForeign)
 import ReportImports(reportFnImports)
---import AuxFile(toAuxFile)
---import AuxLabelAST(auxLabelSyntaxTree)
---import TraceTrans(traceTrans,maybeStripOffQual)
 
 
 --import NonStdProfile
@@ -152,29 +133,6 @@ main' args = do
   pF (sParse flags) "Parse" (prettyPrintTokenId flags ppModule parsedPrg) 
 
 
-{- Now in hat-trans only.
-  {-
-  -- Read and write auxiliary information files (for tracing).
-  -- Then relabel the syntax tree with the auxiliary information.
-  -- Then the tracing transformation itself is applied.
-  -- The result is written to file (no redirection possible yet)
-  -}
-
-  when (sHatTrans flags) $ do
-    let prg = maybeStripOffQual "Prelude" parsedPrg
-    toAuxFile flags (sHatAuxFile flags) prg
-    -- putStr (prettyPrintTokenId flags ppModule prg) -- debug
-    newprog <- auxLabelSyntaxTree flags prg
-    -- putStr (prettyPrintTraceId flags ppModule newprog) -- debug
-    writeFile (sHatTransFile flags)
-      (prettyPrintTokenId flags ppModule 
-        (maybeStripOffQual "TPrelude" 
-          (traceTrans (not (sDbgTrusted flags)) (sSourceFile flags) 
-            (sHatFileBase flags) newprog)))
-    putStrLn ("Wrote " ++ sHatTransFile flags)
-    exitWith (ExitSuccess)
--}
-
   -- (Module _ (Visible modid) _ _ _ _) <- return parsedPrg
   -- Insert check that sPart flags or modid == sourcefile ???
 
@@ -183,15 +141,12 @@ main' args = do
   -- Perform "need" analysis (what imported entities are required?) 
   -- Second argument may contain error message or parse tree
   -}
-  parsedPrg' <- return (
-          dbgAddImport (sDbgTrans flags || sDbgPrelude flags) parsedPrg)
-
   beginPhase "need"
   (need		-- :: NeedTable
    ,qualFun	-- :: TokenId -> [TokenId]
    ,overlap	-- :: Overlap
    ,info)	-- :: Either String (expFun,imports)
-         <- return (needProg flags parsedPrg')
+         <- return (needProg flags parsedPrg)
   (expFun	-- :: (TokenId->Bool) -> TokenId -> IdKind -> IE
    ,imports)	-- :: [ ( PackedString
 		--      , (PackedString, PackedString, Tree (TokenId,IdKind))
@@ -214,7 +169,7 @@ main' args = do
   -- Rename identifiers (also patches fixity information)
   -- Changes from ImportState to IntState
   -}
-  (Module _ (Visible modid) _ impdecls inf decls) <- return parsedPrg'
+  (Module _ (Visible modid) _ impdecls inf decls) <- return parsedPrg
 
   beginPhase "rename"
   (decls	-- :: Decls Id  (renamed from decls :: Decls TokenId)
@@ -263,22 +218,6 @@ main' args = do
          (mixLine (map show (listAT (getSymbolTable state)))) 
 
 
-  {-
-  -- Debugging source-to-source translation of data type definitions.
-  -- For tracing only.
-  -- Transforms data type definitions and all type expressions occurring in
-  -- declarations.
-  -} 
-  beginPhase "dbgdatatrans"
-  (decls	-- :: Decls Id
-   ,state	-- :: IntState
-   ,constrs)	-- :: Maybe [(Pos,Id)]
-             <- return (dbgDataTrans flags state (error "repTree")
-                                     tidFun decls)
-  pF (sTraceData flags) "Abstract syntax tree after tracing type transformation"
-     (prettyPrintId flags state ppTopDecls decls) 
-
-
   {-
   -- Adds arity of all defined variables to symbol table of internal state.
   -- Adds type of variables from type declarations and primitive and foreign
@@ -294,26 +233,6 @@ main' args = do
   catchError (getErrorsIS state) "Errors after extract phase" mixLine
 
 
-  {-
-  -- Debugging source-to-source translation of function definitions 
-  -- (for tracing only)
-  -- Reads the types put into the symbol table of internal state by
-  -- the extract pass.
-  -- sridt :: SRIDTable   (table for source refs and ids for tracing)
-  -}
-  beginPhase "dbgtrans"
-  (decls	-- :: Decls Id
-   ,state	-- :: IntState
-   ,sridt)	-- :: SRIDTable
-          <- return (if sDbgTrans flags 
-                       then debugTrans flags state tidFun modid
-                                       (sSourceFile flags) impdecls
-                                       decls constrs 
-                       else (decls, state, Nothing))
-  pF (sTraceFns flags) "Tracing Transformation on function definitions"
-                       (prettyPrintId flags state ppTopDecls decls) 
-
-
   {-
   -- Create selectors for record fields.
   -- (replace DeclConstrs by definitions for the selectors)
@@ -354,8 +273,7 @@ main' args = do
   (code		-- :: [ClassCode (Exp Id) Id]
    ,decls	-- :: Decls Id
    ,state)	-- :: IntState
-          <- return (typeTopDecls tidFun userDefault state
-                                  code (sDbgTrans flags) decls)
+          <- return (typeTopDecls tidFun userDefault state code decls)
   pF (sType flags) "Declarations after type deriving:" 
          (prettyPrintId flags state ppTopDecls decls) 
   pF (sTBound flags) "Symbol table after type deriving:"  
@@ -387,7 +305,7 @@ main' args = do
   (decls	-- :: [Decl Id]
    ,state	-- :: IntState
    ,t2i)	-- :: Tree (TokenId,Id)
-        <- return (fixSyntax (sDbgTrans flags) decls state tidFun)
+        <- return (fixSyntax decls state tidFun)
   pF (sFixSyntax flags) "Declarations after fixSyntax"
           (prettyPrintId flags state ppTopDecls (DeclsParse decls))
   pF (sFSBound flags) "Symbol table after fixSyntax:"  
@@ -419,8 +337,7 @@ main' args = do
   beginPhase "prim"
   (decls	-- :: [(Id,PosLambda)]
    ,state)	-- :: IntState
-          <- return (primCode primFlags (not (sDbgTrans flags))
-                              tidFun state decls)
+          <- return (primCode primFlags True tidFun state decls)
   pF (sPrim flags) "Declarations after prim expand:" 
           (strPCode (strISInt state) decls) 
   pF (sPBound flags) "Symbol table after prim expand:"  
@@ -489,16 +406,16 @@ main' args = do
   --hSetBuffering handle LineBuffering
   (eslabs	-- :: EmitState
    ,escode)	-- :: EmitState
-       <- if (sAnsiC flags) 
-          then do
-             let eslabs = dbgDumpSRIDTableC Labels handle state flags sridt 
-                              (startEmitState Labels)
-                 escode = dbgDumpSRIDTableC Code   handle state flags sridt 
-                              (startEmitState Code)
-             return (foldr (\a b-> gcodeGather Labels state b a) eslabs zcons
-                    ,foldr (\a b-> gcodeGather Code   state b a) escode zcons)
+       <- let eslabs = startEmitState Labels
+              escode = startEmitState Code in
+          if (sAnsiC flags) 
+          then if null zcons then return (eslabs,escode)
+               else return (foldr (\a b-> gcodeGather Labels state b a)
+                                  (emitWord Labels "42" eslabs) zcons
+                           ,foldr (\a b-> gcodeGather Code   state b a)
+                                  (emitWord Code "42" escode) zcons
+                           )
           else do
-            dbgDumpSRIDTable handle state flags sridt 
             catch (hPutStr handle (gcodeHeader 
                      (foldr ( \ a b -> foldr (gcodeDump state) b a) 
                                              "\n" zcons)))
@@ -508,7 +425,7 @@ main' args = do
                                     ++ sObjectFile flags ++ ":" 
                                     ++ show ioerror ++ "\n")  
                                  exit) 
-            return (startEmitState Labels, startEmitState Code)
+            return (eslabs, escode)
 
 
   {- Generate Gcode for functions -} 
