@@ -8,22 +8,20 @@ import AssocTree
 import Memo
 import Reduce
 import NeedLib(NeedLib,initNeed,needit,popNeed,pushNeed,bindTid,needTid
-              ,NeedTable)
+              ,NeedTable,needQualify)
 import Syntax
 import IdKind
 import PreImport(HideDeclIds,qualRename,preImport)
 import TokenId
-import DbgId(tokenDbg)
 import TokenInt
-import Flags(Flags(sDbgPrelude,sDbgTrans))
+import Flags(Flags)
 import SyntaxPos
 import Extra
 import SyntaxUtil(infixFun)
 
 import Overlap(Overlap)
 import Info(IE)
-import PackedString(PackedString,unpackPS)
-import ImportState(ImportState)
+import SysDeps(PackedString)
 
 
 needProg :: Flags
@@ -44,8 +42,7 @@ needProg :: Flags
 
 needProg flags n@(Module pos modidl exports impdecls fixdecls topdecls) =
   let qualFun = qualRename modidl impdecls
-  in case needit (needModule (sDbgTrans flags || sDbgPrelude flags) n) 
-                 qualFun (initNeed (modidl == tMain)) of
+  in case needit (needModule n) qualFun (initNeed (modidl == tMain)) of
        (need,overlap) -> ( need
                          , qualFun
                          , overlap
@@ -55,9 +52,9 @@ needProg flags n@(Module pos modidl exports impdecls fixdecls topdecls) =
                          )
 
 
-needModule :: Bool -> Module TokenId -> NeedLib -> NeedLib
+needModule :: Module TokenId -> NeedLib -> NeedLib
 
-needModule debugging (Module pos modid exports imports fixdecls topdecls) =
+needModule (Module pos modid exports imports fixdecls topdecls) =
       pushNeed >>>
       bindDataDecls topdecls >>>
       bindDecls topdecls >>>
@@ -71,7 +68,6 @@ needModule debugging (Module pos modid exports imports fixdecls topdecls) =
       mapR needImport imports >>>
       mapR needFixDecl fixdecls >>>
       needDecls topdecls >>>
-      (if debugging then needTids pos tokenDbg else unitR) >>>
       popNeed
 
 
@@ -94,7 +90,7 @@ needEntity q (EntityConClsSome pos hs posidents) = -- TC | TC(id0,id1,...)
     needTid pos TC (q hs)
     >>> needPosIdents q posidents
 
-needPosIdents :: (TokenId->TokenId) -> [(Int,TokenId)] -> NeedLib -> NeedLib
+needPosIdents :: (TokenId->TokenId) -> [(Pos,TokenId)] -> NeedLib -> NeedLib
 needPosIdents q posidents = 
     if any (isTidCon.snd) posidents then
          mapR (\(pos,tid) -> if isTidCon tid then needTid pos Con (q tid)
@@ -174,7 +170,7 @@ needDecl (DeclClass pos tctxs tClass tTVars fundeps (DeclsParse decls)) =
 needDecl (DeclInstance pos ctxs tClass insts (DeclsParse decls)) =
      mapR needCtx ctxs
   >>> mapR needType insts
-  >>> mapR needClassInst decls
+  >>> mapR needClassInst (map (needQualify tClass) decls)
   >>> needTid pos TClass tClass
 
 --        default (type,..)
@@ -304,8 +300,6 @@ needType (TypeCons  pos hs types) = needTid pos TCon hs >>> mapR needType types
 needType (TypeVar   pos hs)       = unitR
 needType (TypeStrict pos typ)     = needType typ
 
-needSig (Sig posidents typ) = needType typ
-
 needSimple kind (Simple pos hs posidents) = needTid pos kind hs -- posidents are typevariables!
 
 needCtx (Context pos hs _) = needTid pos TClass hs
@@ -487,7 +481,7 @@ bindPat (PatNplusK        pos tid _ _ _ _) = bindTid Var tid >>>
 
 
 ------
-needTids :: Int -> [(IdKind,TokenId)] -> NeedLib -> NeedLib
+needTids :: Pos -> [(IdKind,TokenId)] -> NeedLib -> NeedLib
 needTids pos kindtids = mapR (uncurry (needTid pos)) kindtids
 
 
