@@ -9,9 +9,8 @@ module Rename(ctxs2NT, fixInstance, rename) where
 
 import List
 import Syntax
-import Extra(pair,isJust,dropJust,strace,strPos)
 import Bind(bindPat,bindDecls,identPat)
-import RenameLib(ImportState,RenameState,RenameToken,RenameMonad
+import RenameLib(ImportState,RenameState,RenameMonad
                 ,keepRS,is2rs,renameError
                 ,popScope,pushScope,globalTid,fixFixityRS,localTid,defineType
                 ,transTypes,defineDataPrim,uniqueTid,defineDerived,defineData
@@ -19,20 +18,17 @@ import RenameLib(ImportState,RenameState,RenameToken,RenameMonad
                 ,transType,defineDefaultMethod,defineInstMethod,uniqueTVar
                 ,defineField,defineConstr,checkPuns,bindNK)
 import Fixity(fixInfixList)
-import IExtract(tvrPosTids,tvPosTids,freeType,tvTids,countArrows,defFixFun)
-import TokenId(TokenId,t_x,t_Tuple,tTrue,t_error,extractV,t_gtgt
-              ,t_gtgteq{-,tEval-},t_lessequal,t_subtract)
+import IExtract(tvPosTids,freeType,tvTids,countArrows,defFixFun)
+import TokenId(tTrue,t_error,extractV{-,tEval-},t_lessequal,t_subtract)
 import State
 import IdKind
 import Extra
 import NT
 import IntState
-import ImportState(methodsI,uniqueI,tidI)
 import AssocTree
-import TokenInt
-import PackedString(PackedString,packString,unpackPS)
+import SysDeps(PackedString,unpackPS)
 import SyntaxPos
-import SyntaxUtil(infixFun)
+import SyntaxUtil(infixFun,isTypeVar)
 import Id(Id)
 
 import Overlap(Overlap)
@@ -100,29 +96,33 @@ groupFun (DeclsParse decls) = DeclsParse (groupFun' decls)
   groupFun' [] = []
   groupFun' (d@(DeclFun _ _ [Fun [] _ _]):r) = d: groupFun' r
   groupFun' (DeclFun pos fun funs:r) =
-    DeclFun pos fun (funs++funs'):    groupFun' r'
+    DeclFun (mergePos pos (getPos funs')) fun (funs++funs'): groupFun' r'
     where 
     (funs',r') =     groupFun'' fun [] r
   groupFun' (d@(DeclPat (Alt (ExpVar pos fun) gdexps w)):r) = 
-    groupFun' (DeclFun pos fun [Fun [] gdexps w]:r)
+    groupFun' (DeclFun (mergePoss [pos,getPos gdexps,getPos w]) fun 
+                 [Fun [] gdexps w]:r)
   groupFun' (d@(DeclPat (Alt (ExpInfixList pos es) gdexps w)):r) = 
     case infixFun es of
       Nothing -> d: groupFun' r
       Just (e1,pos',fun',e2) -> 
-        groupFun' (DeclFun pos' fun' [Fun [e1,e2] gdexps w]:r)
-  groupFun' (d:r) = d:    groupFun' r
+        groupFun' (DeclFun (mergePoss [pos,getPos gdexps,getPos w]) fun' 
+                     [Fun [e1,e2] gdexps w]:r)
+  groupFun' (d:r) = d: groupFun' r
 
   groupFun'' :: Eq a => a -> [Fun a] -> [Decl a] -> ([Fun a],[Decl a])
 
   groupFun'' fun acc (DeclFun pos fun' funs:r) | fun == fun' =
     groupFun'' fun (acc++funs) r
   groupFun'' fun acc  (d@(DeclPat (Alt (ExpVar pos fun') gdexps w)):r) = 
-    groupFun'' fun acc  (DeclFun pos fun' [Fun [] gdexps w]:r)
+    groupFun'' fun acc  (DeclFun (mergePoss [pos,getPos gdexps,getPos w]) fun' 
+                           [Fun [] gdexps w]:r)
   groupFun'' fun acc dr@(DeclPat (Alt (ExpInfixList pos es) gdexps w):r) = 
     case infixFun es of
       Nothing -> (acc,dr)
       Just (e1,pos',fun',e2) -> 
-        groupFun'' fun acc  (DeclFun pos' fun' [Fun [e1,e2] gdexps w]:r)
+        groupFun'' fun acc  (DeclFun (mergePoss [pos,getPos gdexps,getPos w]) 
+                               fun' [Fun [e1,e2] gdexps w]:r)
   groupFun'' fun acc r = (acc,r)
 
 
@@ -224,7 +224,7 @@ renameDecl (DeclType (Simple pos tid tvs) typ) =
 
 renameDecl (DeclDataPrim  pos tid size) =
   uniqueTid pos TCon tid >>>= \i ->
-  defineDataPrim tid (NewType [] [] [] [NTcons i []]) size >>>= \d ->
+  defineDataPrim tid (NewType [] [] [] [mkNTcons i []]) size >>>= \d ->
   unitS (DeclConstrs pos d [])
 
 renameDecl (DeclData b ctxs (Simple pos tid tvs) constrs posidents) =
@@ -238,7 +238,7 @@ renameDecl (DeclData b ctxs (Simple pos tid tvs) constrs posidents) =
      {- example:
         data Num a => Test a b = A a | B b
         nt = NewType [1,2] [] [(NumId, 1)] 
-               [NTvar 1, NTvar 2, NTcons TestId [NTvar 1, NTvar 2]]
+               [mkNTvar 1, mkNTvar 2, mkNTcons TestId [mkNTvar 1, mkNTvar 2]]
      -}
      mapS (renameConstr tid al ctxs (last nts)) constrs >>>= \csfields ->
      let (cs,noargs,fields) = unzip3 csfields 
@@ -267,8 +267,8 @@ renameDecl (DeclClass pos ctxs tid (tvar:_) _ decls') =
                   ++") are not supported.")
                  (DeclClass pos [] c [t] [] (DeclsParse []))
 
-renameDecl (DeclInstance pos ctxs tid [instanceType@(TypeCons _ tcon _)]
-                         instmethods') =
+renameDecl (DeclInstance pos ctxs tid [instanceType@(TypeCons _ tcon tvs)]
+                         instmethods') | all isTypeVar tvs =
   let al = tvTids (snub (freeType instanceType))
       (DeclsParse instmethods) = groupFun instmethods'
   in mapS (renameCtx al) ctxs >>>= \ ctxs -> 
@@ -459,12 +459,14 @@ renameFun (Fun pats rhs decls') =
  let decls = groupFun decls'
  in pushScope >>>
     	mapS0 (bindPat Var) pats >>>
+        pushScope >>>
     	bindDecls decls >>>
 	renameDecls decls >>>= \newdecls ->	-- do first, to get infix right
     unitS Fun =>>>
 	mapS renameExp pats =>>>
 	renameRhs rhs =>>>
         unitS newdecls >>>
+        popScope >>>
     popScope
 
 
@@ -537,16 +539,16 @@ renameConstr :: TokenId          {- type constructor of data/newtype def. -}
              -> [(Id,Id)]        {- context of the data/newtype def. -} 
              -> NT               {- defined type (type constructor with vars)-}
              -> Constr TokenId   {- constructor with type arguments -}
-             -> RenameMonad (Id,Bool,[(Int,Int,Int)]) 
+             -> RenameMonad (Id,Bool,[(Pos,Int,Int)]) 
                   {- constructor id, no arguments, fields -}
 
-renameConstr typtid al ctxs resType@(NTcons bt _) 
+renameConstr typtid al ctxs resType@(NTcons bt _ _) 
                             c@(Constr pos tid fieldtypes) =
   let e =  [] -- no forall if Constr is used
       es = zip e [1 + length al .. ]
   in
     mapS (transFieldType (es++al)) fieldtypes >>>= \ntss ->
-    let all = concat (ntss :: [[(Maybe (Int,TokenId,Int),NT)]])
+    let all = concat (ntss :: [[(Maybe (Pos,TokenId,Int),NT)]])
 	nts = map snd all
         ifs :: [Maybe Id]
 	ifs = map ( (\v -> case v of Just (p,tid,i) -> Just i; _ -> Nothing) 
@@ -558,9 +560,9 @@ renameConstr typtid al ctxs resType@(NTcons bt _)
       mapS (defineField typtid bt c) (zip all [ 1:: Int ..]) >>>= \ fs ->
       unitS (c,null nts,map dropJust (filter isJust fs))
 
-renameConstr typtid al ctxs resType@(NTcons bt _) 
+renameConstr typtid al ctxs resType@(NTcons bt _ _) 
                             (ConstrCtx forall ectxs' pos tid fieldtypes) =
-  let ce = map ( \( Context _ _ [(_,v)]) -> v) ectxs'
+  let -- ce = map ( \( Context _ _ [(_,v)]) -> v) ectxs'
       e =  map snd forall 
             -- filter (`notElem` (map fst al)) $ snub $  (ce ++) $ 
             -- concat $ map (freeType . snd) fieldtypes
@@ -677,7 +679,6 @@ renameExp (PatNplusK pos tid _ k _ _) =
     let leq = ExpVar pos t_lessequal
         sub = ExpVar pos t_subtract
         n'  = ExpVar pos tid'
-        n   = ExpVar pos tid 
     in
     unitS (PatNplusK pos) =>>>
       uniqueTid pos Var tid =>>>
@@ -702,9 +703,9 @@ fixInstance iTrue (DeclInstance pos ctxs i [instanceType@(TypeCons _ ti tvs)]
     mapS (\(pos,i) -> getInfo i >>>= \info -> unitS (pos,info))
          (map getI instmethods) >>>= \ ims ->
     let
-      free = map ( \ (TypeVar _ v) -> v) tvs
+      free = concatMap (\tv-> case tv of (TypeVar _ v) -> [v]; _ -> []) tvs
       ctxsNT =  ctxs2NT ctxs
-      nt = NewType free [] ctxsNT [NTcons ti (map NTvar free)]
+      nt = NewType free [] ctxsNT [mkNTcons ti (map mkNTvar free)]
       cmds' = map ( \ (info,d) -> (extractV (tidI info),(info,d))) cmds
       old = map ( \ (pos,info) -> (pos,extractV (tidI info),info)) ims      
       dms = map snd3 old
