@@ -1,27 +1,27 @@
 {- ---------------------------------------------------------------------------
 -}
 module RenameLib(module RenameLib
-	,AssocTree(..)
+	,AssocTree
 	,Tree ,ImportState,NT,NewType,IE,Either,Info
-	,Maybe,Flags(..)) where
+	,Maybe,Flags) where
 
 import List
 import TokenId(TokenId(..),t_Tuple,ensureM,mkQual2,visible,mkQual3,mkQualD
-              ,extractV,rpsPrelude,forceM)
-import Syntax
+              ,rpsPrelude,forceM)
+import Syntax hiding (TokenId)
 import Scc
 import NT
 import Extra
 
 import AssocTree
-import ImportState
+import ImportState hiding (TokenId)
 import IntState(checkNT)
-import IExtract(tvPosTids,tvTids,freeType,fixOne,fixFun)
+import IExtract(fixOne,fixFun)
 import State
 import IdKind
 import PreImp(sExp,sQual,sLG,sFix)
-import PackedString(PackedString,packString,unpackPS)
-import Info
+import SysDeps(PackedString,unpackPS)
+import Info hiding (TokenId)
 import SyntaxPos
 import TokenInt
 import OsOnly(isPrelude)
@@ -149,7 +149,7 @@ keepRS (RenameState flags unique rps rts rt st derived
           case depthI info of
 	    Just _ ->  -- type synonym, so follow the chain
 	      case ntI info of
-		(NewType free [] ctx [NTcons u' _]) ->
+		(NewType free [] ctx [NTcons u' _ _]) ->
 		  isUnBoxedNT st nt (u:ac) u'	      
 	    Nothing -> -- newtype, so follow the chain
 	      case lookup u nt of
@@ -159,7 +159,7 @@ keepRS (RenameState flags unique rps rts rt st derived
                   case constrsI info of
                     (coni:_) ->
                       case (ntI . dropJust . lookupAT st) coni of
-                        (NewType _ _ _ [NTcons u' _,_]) ->
+                        (NewType _ _ _ [NTcons u' _ _,_]) ->
                           isUnBoxedNT st nt (u:ac) u'
                         _ -> -- strace 
                       -- ("Warning: renaming newtype of imported newtype:\n"++
@@ -182,7 +182,7 @@ keepRS (RenameState flags unique rps rts rt st derived
         case depthI info of
 	  Just _ ->  -- type synonym
 	    case ntI info of
-	      (NewType free [] ctx [NTcons u' _]) ->
+	      (NewType free [] ctx [NTcons u' _ _]) ->
 	        isUnBoxedTS st u'	      
               _ ->  -- FAKE This is a BUG but unboxed is not used anyway
                 False
@@ -215,8 +215,8 @@ keepRS (RenameState flags unique rps rts rt st derived
             case constrsI info of
 	      (coni:_) ->
 		 case (ntI . dropJust . lookupAT st ) coni of
-  	           (NewType _ [] _ [NTcons c _,res]) -> (synType,(u,c):newType)
-  	           (NewType _ [] _ [NTvar v,res]) -> (synType,(u,v):newType)
+  	           (NewType _ [] _ [NTcons c _ _,res]) -> (synType,(u,c):newType)
+  	           (NewType _ [] _ [NTvar v _,res]) -> (synType,(u,v):newType)
   	           (NewType _ [] _ [NTapp v1 v2,res]) -> (synType,newType)
 			-- ^ MW hack: omits potential circularity check!
   	           (NewType _ [] _ (_:_:_)) ->
@@ -552,7 +552,7 @@ transTypes al free ctxs ts =
   mapS (transType al) ts
 
 transTVar pos al v =
-  unitS NTvar =>>> uniqueTVar pos al v
+  unitS mkNTvar =>>> uniqueTVar pos al v	-- no KIND inference
 
 uniqueTVar pos al v =
   case lookup v al of
@@ -569,7 +569,7 @@ transType :: [(TokenId,Int)] -> Type TokenId -> RenameMonad NT
 transType al (TypeApp  t1 t2) = 
   unitS NTapp =>>> transType al t1 =>>> transType al t2
 transType al (TypeCons  pos hs types) = 
-  unitS NTcons =>>> uniqueTid pos TCon hs =>>> mapS (transType al) types
+  unitS mkNTcons =>>> uniqueTid pos TCon hs =>>> mapS (transType al) types
 transType al (TypeVar   pos v) = transTVar pos al v
 transType al (TypeStrict pos t) = unitS NTstrict =>>> transType al t
 
@@ -685,14 +685,14 @@ defineData d tid nt cs down (RenameState flags unique irps@(_,rps) rts rt st
       key = (tid,TCon)
   in case lookupAT rt key of
        Just u ->
-         let (needCheck',dk) =
+         let (needCheck',dk,patch) =
 		case d of
-		  Just unboxed -> (needCheck,Data unboxed cs)
-		  Nothing -> (u:needCheck,DataNewType False cs) 
+		  Just unboxed -> (needCheck,   Data unboxed cs,      id)
+		  Nothing -> (u:needCheck, DataNewType False cs, patchIE)
                               -- unboxed fixed by keepRS
 	 in (u,RenameState flags unique irps rts rt 
 		 (addAT st combInfo u {-(realtid,TCon)-} 
-                    (InfoData u realtid (sExp down tid TCon) nt dk))
+                    (InfoData u realtid (patch (sExp down tid TCon)) nt dk))
 		 derived defaults errors needCheck')
 
 
@@ -793,6 +793,7 @@ defineField typtid bt c ((Just (p,tid,_),_),i) down
                                      (InfoVar selu realtid
                                           (case sExp down typtid TCon of
 					      IEall -> IEsel
+					   -- IEsome -> sExp down tid Field
 					   -- IEabs -> sExp down tid Var
                                               _     -> sExp down tid Var)
                                           (sFix down realtid)
@@ -856,7 +857,6 @@ defineInstMethod tid  down (RenameState flags unique irps@(_,rps)
                                         errors needCheck) = 
   let realtid = mkQual2 (t_Tuple unique) (ensureM rps tid)
                 -- this is obscure! why a tuple with the size of unique?
-      key = (tid,MethodInstance)
   in (unique,RenameState flags (unique+1) irps rts rt
 		 (addAT st combInfo  unique {-(realtid,MethodInstance)-}
                         (InfoIMethod unique realtid NoType Nothing (0::Int)))
