@@ -8,7 +8,7 @@ import IdKind
 import State
 import NT
 import TypeLib(typeUnify,typeUnifyMany,typeUnifyApply,typePatCon,typeExpCon
-              ,typeIdentDict,debugTranslating,getIdent,getTypeErrors,typeError
+              ,typeIdentDict,getIdent,getTypeErrors,typeError
               ,typeNewTVar,typeIdentDef,checkExist,funType,extendEnv,getEnv
               ,getState,setState
               ,msgFun,msgPat,msgLit,msgBool,msgGdExps,msgAltExps,msgCase
@@ -19,8 +19,6 @@ import MergeSort(group,unique)
 import TypeSubst
 import TypeCtx
 import TypeData
-import PackedString(PackedString,packString,unpackPS)
-import Info
 import IntState
 import TypeUtil(ntIS)
 import TypeUnify(unify)
@@ -34,12 +32,12 @@ import Id(Id)
 --import PPSyntax   -- just for debugging
 --import StrSyntax  -- just for debugging
 
-typeTopDecls tidFun defaults state code dbgtrans topdecls =
+typeTopDecls tidFun defaults state code topdecls =
   let defaults' =
         case defaults of
 	  Nothing -> [tidFun (tInteger,TCon),tidFun (tDouble,TCon)]
 	  Just def -> def 
-      result =  typeTopDeclScc topdecls tidFun defaults' dbgtrans finalState state
+      result =  typeTopDeclScc topdecls tidFun defaults' finalState state
       finalState = snd result
   in case result of
        (topdecls,state) ->
@@ -55,18 +53,18 @@ typeCode (CodeInstance pos cls typ _ _ ms) tidFun state =
   in case uniqueISs state ctxs of
       (ctxsi,state) ->
 	(CodeInstance pos cls typ (map snd ctxsi)
-	     (map (buildCtx state noPos (map (mapFst (mapSnd NTvar)) ctxsi) . ( \ cls -> TypeDict cls (NTcons typ (map NTvar free)) [(0,pos)])) sc) ms
+	     (map (buildCtx state noPos (map (mapFst (mapSnd mkNTvar)) ctxsi) . ( \ cls -> TypeDict cls (mkNTcons typ (map mkNTvar free)) [(0,pos)])) sc) ms
 	,state)
 
 
 typeTopDeclScc :: Decls Id 
                -> ((TokenId,IdKind) -> Int) 
-               -> [Id] -> Bool -> a 
+               -> [Id] -> a 
                -> IntState 
                -> (Decls Id,IntState)
 
-typeTopDeclScc (DeclsScc xs) tidFun defaults dbgtrans finalState state =
-     case mapS typeDepend xs (TypeDown initEnv tidFun defaults [] [] dbgtrans) (TypeState state idSubst initCtxs []) of
+typeTopDeclScc (DeclsScc xs) tidFun defaults finalState state =
+     case mapS typeDepend xs (TypeDown initEnv tidFun defaults [] []) (TypeState state idSubst initCtxs []) of
 	(xs,TypeState state phi ctxs ectxsi) -> (DeclsScc (concat xs),state)
 
 
@@ -90,7 +88,7 @@ typeDepend (DeclsRec ds13) =
 typeScc :: [Decl Id] 
         -> TypeDown -> TypeState -> (([Decl Id],[Decl Id]),TypeState)
 
-typeScc decls down@(TypeDown env tidFun defaults ctxsDict envDict dbgtrans)
+typeScc decls down@(TypeDown env tidFun defaults ctxsDict envDict)
               up@(TypeState state phi inCtxs ectxsi) = 
   let -- ctxs should only get up but the monad can not handle that!
       trueExp :: Exp Id  -- this expression has become superfluous,
@@ -101,15 +99,15 @@ typeScc decls down@(TypeDown env tidFun defaults ctxsDict envDict dbgtrans)
       (nextTvar,_) = uniqueIS state -- take a look at the next type variable
 
       envHere :: [(Int, NT)]
-      (envHere,up'@(TypeState state' phi' ctxs' ectxsi')) =
+      (envHere,up') =
 		envDecls decls () (TypeState state phi initCtxs [])
 
       decls' :: [Decl Int]
-      (decls',up''@(TypeState state'' phi'' ctxs'' existCtxsi)) =
+      (decls', TypeState state'' phi'' ctxs'' existCtxsi) =
 		mapS typeDecl decls
                      (TypeDown (envHere++env) tidFun defaults
                                (usedCtx ++ ctxsDict)
-                               (derivedDict ++ envDict) dbgtrans)
+                               (derivedDict ++ envDict))
                      up'
 
       phiEnv :: [(Int,NT)]
@@ -211,8 +209,8 @@ typeScc decls down@(TypeDown env tidFun defaults ctxsDict envDict dbgtrans)
 
 --------------------- Fix arguments and types
 
-isExist (NTexist _) = True
-isExist _           = False
+isExist (NTexist _ _) = True
+isExist _             = False
 
 
 bindType :: Decl Id 
@@ -257,7 +255,7 @@ bindType decl@(DeclPat (Alt pat gdexps decls))
   errmsg = "Context for " ++ mixCommaAnd ((map (strIS state) . unique .
                                            map (fst . fst)) localCtxsi)
 	   ++ " needed in left hand pattern at " ++ strPos (getPos pat) ++ "."
-  nt = NewType [1] [] [] [NTvar 1]   -- Used instead of derived type, not sure
+  nt = NewType [1] [] [] [mkNTvar 1] -- Used instead of derived type, not sure
                                      -- if it is any idea
   typeError (pos,ident) state = (updateIS state ident (newNT nt))
 
@@ -298,7 +296,6 @@ bindType decl@(DeclFun pos fun funs)
 
     (given@(NewType givenFree [] givenCtx [givenNT]),state) -> 
       let derivedNT = assocDef envHere (error "171")  fun
-	  derivedFree = filter (`notElem` globalTVars) (snub (freeNT derivedNT))
       in
       case unify state idSubst (derivedNT,givenNT) of 
         Left (phi,err) ->
@@ -316,10 +313,10 @@ bindType decl@(DeclFun pos fun funs)
 
               al = mkAL (givenFree ++ freeNT derivedNT)
 
-	      fixSubst (v,NTvar v') = if v `elem` givenFree then (v',NTvar v)
-                                                            else (v,NTvar v')
-	      fixSubst (v,NTany v') = if v `elem` givenFree then (v',NTvar v)
-                                                            else (v,NTvar v')
+	      fixSubst (v,NTvar v' k) = if v`elem`givenFree then (v',NTvar v k)
+                                                            else (v,NTvar v' k)
+	      fixSubst (v,NTany v')   = if v`elem`givenFree then (v',mkNTvar v)
+                                                            else (v,mkNTvar v')
               fixSubst p = p
 
               one2many phi = ( filter ((/= 1).length.snd)
@@ -334,13 +331,13 @@ bindType decl@(DeclFun pos fun funs)
                          Nothing -> Just v
                          Just xs -> findV xs
 
-              findV [NTvar v] = Just v
+              findV [NTvar v _] = Just v
               findV [NTany v] = Just v
               findV _ = Nothing
 
 	      sameNT (NTany _) v   = NTany v
-	      sameNT (NTvar _) v   = NTvar v
-	      sameNT (NTexist _) v = NTexist v
+	      sameNT (NTvar _ k) v   = NTvar v k
+	      sameNT (NTexist _ k) v = NTexist v k
 
 
               localCtxi' = ( map dropJust
@@ -391,7 +388,7 @@ bindType decl@(DeclFun pos fun funs)
                 let sOne2Many xs =
                         concatMap (\(v,nts)->
                                    "\n    type variable "
-                                   ++ niceNT Nothing state al (NTvar v)
+                                   ++ niceNT Nothing state al (mkNTvar v)
                                    ++ " bound to "
 			           ++ mixCommaAnd (map (niceNT Nothing state al)
                                                         nts)
@@ -399,12 +396,12 @@ bindType decl@(DeclFun pos fun funs)
                     sFreeBound [] = []
                     sFreeBound [(v,t)] =
                         "\n    given free variable "
-                        ++ niceNT Nothing state al (NTvar v)
+                        ++ niceNT Nothing state al (mkNTvar v)
                         ++ " is bound to " ++ niceNT Nothing state al (head t)
                     sFreeBound xs =
                         "\n    given free variables "
                         ++ mixCommaAnd (map (niceNT Nothing state al
-                                            . NTvar . fst) xs)
+                                            . mkNTvar . fst) xs)
                         ++ " are bound to "
                         ++ mixCommaAnd (map (niceNT Nothing state al
                                             . head . snd) xs)
@@ -491,39 +488,31 @@ typeFun fun arrow funT retT (Fun args13 rhs decls) =
 
 
 typeLit e@(ExpLit pos (LitInteger _ _)) =    --- Add fromInteger
-  debugTranslating >>>= \dbgtrans ->
-  if dbgtrans then
-      getIdent (tInteger,TCon) >>>= \tcon -> unitS (e,NTcons tcon [])
-  else
       getIdent (tInteger,TCon) >>>= \ tcon ->
       getIdent (tfromInteger,Var) >>>= \ tfromInteger ->
       typeIdentDict (ExpVar pos) pos tfromInteger >>>= \ (exp,expT) ->
-      typeUnifyApply (msgLit pos "integer") [expT,NTcons tcon []] >>>= \ t ->
+      typeUnifyApply (msgLit pos "integer") [expT,mkNTcons tcon []] >>>= \ t ->
       unitS (ExpApplication pos [exp,e],t)
 typeLit e@(ExpLit pos (LitRational _ _)) =	--- Add fromRational
-  debugTranslating >>>= \dbgtrans ->
-  if dbgtrans then
-      getIdent (tRational,TCon) >>>= \tcon -> unitS (e,NTcons tcon [])
-  else
       getIdent (tRational,TCon) >>>= \ tcon ->
       getIdent (tfromRational,Var) >>>= \ tfromRational ->
       typeIdentDict (ExpVar pos) pos tfromRational >>>= \ (exp,expT) ->
-      typeUnifyApply (msgLit pos "rational") [expT,NTcons tcon []] >>>= \ t ->
+      typeUnifyApply (msgLit pos "rational") [expT,mkNTcons tcon []] >>>= \ t ->
       unitS (ExpApplication pos [exp,e],t)
 typeLit e@(ExpLit pos (LitString _ _)) = getIdent (tString,TCon) >>>= \tcon ->
-                                         unitS (e,NTcons tcon [])
+                                         unitS (e,mkNTcons tcon [])
 typeLit e@(ExpLit pos (LitInt _ _))    = getIdent (tInt,TCon)    >>>= \tcon ->
-                                         unitS (e,NTcons tcon [])
+                                         unitS (e,mkNTcons tcon [])
 typeLit e@(ExpLit pos (LitFloat _ _))  = getIdent (tFloat,TCon)  >>>= \tcon ->
-                                         unitS (e,NTcons tcon [])
+                                         unitS (e,mkNTcons tcon [])
 typeLit e@(ExpLit pos (LitDouble _ _)) = getIdent (tDouble,TCon) >>>= \tcon ->
-                                         unitS (e,NTcons tcon [])
+                                         unitS (e,mkNTcons tcon [])
 typeLit e@(ExpLit pos (LitChar _ _))   = getIdent (tChar,TCon)   >>>= \tcon ->
-                                         unitS (e,NTcons tcon [])
+                                         unitS (e,mkNTcons tcon [])
 
 typeUnifyBool g t =
   getIdent (tBool,TCon) >>>= \ tcon ->
-  typeUnify (msgBool g) (NTcons tcon []) t
+  typeUnify (msgBool g) (mkNTcons tcon []) t
 
 typeGdExp (g,e) =
   typeExp g >>>= \(g,gT) ->
@@ -599,9 +588,7 @@ typeExp (ExpList  pos es)         =
    (es,esT) -> 
      typeUnifyMany (msgList es) esT >>>= \t ->
      getIdent (t_List,TCon)     >>>= \tcon ->
-     unitS (ExpList pos es,NTcons tcon [t])
- where
-  mapL = map :: ((a->b) -> [a] -> [b])
+     unitS (ExpList pos es,mkNTcons tcon [t])
 
 typeExp (ExpLambda pos pats13 exp)  =
 --  phiMark >>>= \ mark ->
@@ -626,14 +613,14 @@ typeExp (ExpType pos exp ctxs t) = -- Ignoring ctx and doesn't check if the
                                    -- free variables really are free !!!
   (if not (null ctxs) 
   then strace ("Context at " ++ strPos (getPos ctxs)
-              ++ " in typed expression is ignored :-(")
+              ++ " in type-annotated expression is ignored :-(\n")
   else id) $
   typeExp exp >>>= \ (exp,expT) ->
   let nt = type2NT t
       free = snub (freeNT nt)
   in 
     mapS (\ _ -> typeNewTVar) free >>>= \ free' -> 
-    let phi = list2Subst (zip free (map ( \ (NTany a) -> NTvar a) free')) 
+    let phi = list2Subst (zip free (map (\(NTany a) -> mkNTvar a) free')) 
     in typeUnify (msgExpType pos) (subst phi nt) expT >>>= \ expT ->
        unitS (exp,expT)
 
@@ -673,22 +660,20 @@ typePat (ExpList  pos es)         =
    (es,esT,eTVar) -> 
      typeUnifyMany (msgList es) esT >>>= \t ->
      getIdent (t_List,TCon)     >>>= \tcon ->
-     unitS (ExpList pos es,NTcons tcon [t],concat eTVar)
- where
-  mapL = map :: ((a->b) -> [a] -> [b])
+     unitS (ExpList pos es,mkNTcons tcon [t],concat eTVar)
 
 typePat (ExpType pos exp ctxs t) = -- Ignoring ctx and doesn't check if the
                                    -- free variables really are free !!!
   (if not (null ctxs) 
   then strace ("Context at " ++ strPos (getPos ctxs)
-              ++ " in typed expression is ignored :-(")
+              ++ " in type-annotated pattern is ignored :-(\n")
   else id) $
   typePat exp >>>= \ (exp,expT,eTVar) ->
   let nt = type2NT t
       free = snub (freeNT nt)
   in 
     mapS (\ _ -> typeNewTVar) free >>>= \ free' -> 
-    let phi = list2Subst (zip free (map ( \ (NTany a) -> NTvar a) free')) 
+    let phi = list2Subst (zip free (map (\(NTany a) -> mkNTvar a) free')) 
     in typeUnify (msgExpType pos) (subst phi nt) expT >>>= \ expT ->
        unitS (exp,expT,eTVar)
 
