@@ -1,6 +1,6 @@
 #include <haskell2c.h>
 #include "cLowUnboxedArray.h"
-#include "localmalloc.h"
+#include <stdlib.h>
 
 void * hs_allocUBA (int size,unsigned int end)
 { UBA uba;
