@@ -14,7 +14,7 @@ foreign import ccall hs_compareBin :: Int -> Int -> ForeignObj -> Int -> Foreign
 
 compareBin :: Int -> Int -> BinHandle -> BinPtr -> BinHandle -> BinPtr -> Ordering
 compareBin sizex sizey (BH bhx) (BP x) (BH bhy) (BP y) =
-  let retval = hs_compareBin sizex sizey bhx x bhy y
-  in (toEnum retval)
+  let retval = hs_compareBin sizex sizey bhx x bhy y in
+  (toEnum retval)
 
 
