@@ -11,7 +11,7 @@ foreign import ccall hs_equalsBin :: Int -> ForeignObj -> Int -> ForeignObj -> I
 
 equalsBin :: Int -> BinHandle -> BinPtr -> BinHandle -> BinPtr -> Bool
 equalsBin size (BH bhx) (BP x) (BH bhy) (BP y) =
-  let retval = hs_equalsBin size bhx x bhy y
-  in retval
+  let retval = hs_equalsBin size bhx x bhy y in
+  retval
 
 
