@@ -10,8 +10,8 @@ foreign import ccall hs_stdmem :: ForeignObj
 
 stdmem :: BinHandle
 stdmem =
-  let bh = hs_stdmem
-  in (BH bh)
+  let bh = hs_stdmem in
+  (BH bh)
 
 
 
