@@ -18,9 +18,9 @@ foreign import ccall hs_opendir :: PackedString -> IO (Int,ForeignObj)
 
 opendir :: FilePath -> IO (Int,Dir)
 opendir tmp1 =
-  let fp = toCString tmp1
-  in do (err,d) <- hs_opendir fp
-	return (err,(Dir d))
+  do let fp = toCString tmp1
+     (err,d) <- hs_opendir fp
+     return (err,(Dir d))
 
 
 
