@@ -10,9 +10,9 @@ foreign import ccall hs_getperms :: PackedString -> IO (Int,(Bool,Bool,Bool,Bool
 
 getperms :: FilePath -> IO (Int,Permissions)
 getperms tmp1 =
-  let fp = toCString tmp1
-  in do (err,(r,w,x,s)) <- hs_getperms fp
-	return (err,(toPerm (r,w,x,s)))
+  do let fp = toCString tmp1
+     (err,(r,w,x,s)) <- hs_getperms fp
+     return (err,(toPerm (r,w,x,s)))
 
 
 
