@@ -1,144 +1,104 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v444	((void*)startLabel+36)
-#define CT_v446	((void*)startLabel+84)
-#define CT_v448	((void*)startLabel+140)
-#define CT_v450	((void*)startLabel+196)
-#define CT_v452	((void*)startLabel+244)
-#define CT_v454	((void*)startLabel+292)
-#define CT_v456	((void*)startLabel+348)
-#define CT_v458	((void*)startLabel+404)
-#define CT_v460	((void*)startLabel+460)
-#define CT_v462	((void*)startLabel+512)
-#define CT_v464	((void*)startLabel+564)
-#define CT_v466	((void*)startLabel+616)
-#define CT_v468	((void*)startLabel+696)
-#define FN_LAMBDA441	((void*)startLabel+744)
-#define CT_v471	((void*)startLabel+776)
-#define CF_LAMBDA441	((void*)startLabel+784)
-#define CT_v473	((void*)startLabel+820)
-#define CT_v475	((void*)startLabel+872)
-#define CT_v477	((void*)startLabel+924)
-#define CT_v479	((void*)startLabel+988)
-#define CT_v481	((void*)startLabel+1044)
-#define CT_v483	((void*)startLabel+1100)
-#define CT_v485	((void*)startLabel+1156)
-#define CT_v487	((void*)startLabel+1212)
-#define CT_v489	((void*)startLabel+1268)
-#define CT_v491	((void*)startLabel+1324)
-#define CT_v493	((void*)startLabel+1392)
-#define CT_v495	((void*)startLabel+1444)
-#define CT_v497	((void*)startLabel+1504)
-#define CT_v499	((void*)startLabel+1576)
-#define CT_v501	((void*)startLabel+1664)
-#define CT_v503	((void*)startLabel+1744)
-#define ST_v470	((void*)startLabel+1788)
-#define ST_v445	((void*)startLabel+1791)
-#define ST_v443	((void*)startLabel+1809)
-#define ST_v449	((void*)startLabel+1827)
-#define ST_v447	((void*)startLabel+1844)
-#define ST_v502	((void*)startLabel+1861)
-#define ST_v461	((void*)startLabel+1887)
-#define ST_v459	((void*)startLabel+1922)
-#define ST_v455	((void*)startLabel+1961)
-#define ST_v457	((void*)startLabel+2002)
-#define ST_v451	((void*)startLabel+2039)
-#define ST_v465	((void*)startLabel+2074)
-#define ST_v463	((void*)startLabel+2105)
-#define ST_v453	((void*)startLabel+2136)
-#define ST_v496	((void*)startLabel+2169)
-#define ST_v494	((void*)startLabel+2193)
-#define ST_v492	((void*)startLabel+2220)
-#define ST_v498	((void*)startLabel+2247)
-#define ST_v488	((void*)startLabel+2272)
-#define ST_v490	((void*)startLabel+2299)
-#define ST_v484	((void*)startLabel+2327)
-#define ST_v486	((void*)startLabel+2354)
-#define ST_v478	((void*)startLabel+2382)
-#define ST_v482	((void*)startLabel+2415)
-#define ST_v480	((void*)startLabel+2444)
-#define ST_v500	((void*)startLabel+2473)
-#define ST_v472	((void*)startLabel+2499)
-#define ST_v476	((void*)startLabel+2530)
-#define ST_v467	((void*)startLabel+2565)
-#define ST_v469	((void*)startLabel+2601)
-#define ST_v474	((void*)startLabel+2643)
+#define CT_v447	((void*)startLabel+36)
+#define CT_v449	((void*)startLabel+84)
+#define CT_v451	((void*)startLabel+140)
+#define CT_v453	((void*)startLabel+196)
+#define CT_v455	((void*)startLabel+244)
+#define CT_v457	((void*)startLabel+292)
+#define CT_v459	((void*)startLabel+348)
+#define CT_v461	((void*)startLabel+404)
+#define CT_v463	((void*)startLabel+460)
+#define CT_v465	((void*)startLabel+512)
+#define CT_v467	((void*)startLabel+564)
+#define CT_v469	((void*)startLabel+616)
+#define CT_v471	((void*)startLabel+696)
+#define FN_LAMBDA444	((void*)startLabel+744)
+#define CT_v474	((void*)startLabel+776)
+#define CF_LAMBDA444	((void*)startLabel+784)
+#define CT_v476	((void*)startLabel+820)
+#define CT_v478	((void*)startLabel+872)
+#define CT_v480	((void*)startLabel+924)
+#define CT_v482	((void*)startLabel+988)
+#define CT_v484	((void*)startLabel+1044)
+#define CT_v486	((void*)startLabel+1100)
+#define CT_v488	((void*)startLabel+1156)
+#define CT_v490	((void*)startLabel+1212)
+#define CT_v492	((void*)startLabel+1268)
+#define CT_v494	((void*)startLabel+1324)
+#define CT_v496	((void*)startLabel+1392)
+#define CT_v498	((void*)startLabel+1444)
+#define CT_v500	((void*)startLabel+1504)
+#define CT_v502	((void*)startLabel+1576)
+#define CT_v504	((void*)startLabel+1664)
+#define CT_v506	((void*)startLabel+1744)
+#define ST_v473	((void*)startLabel+1788)
+#define ST_v448	((void*)startLabel+1791)
+#define ST_v446	((void*)startLabel+1809)
+#define ST_v452	((void*)startLabel+1827)
+#define ST_v450	((void*)startLabel+1844)
+#define ST_v505	((void*)startLabel+1861)
+#define ST_v464	((void*)startLabel+1887)
+#define ST_v462	((void*)startLabel+1922)
+#define ST_v458	((void*)startLabel+1961)
+#define ST_v460	((void*)startLabel+2002)
+#define ST_v454	((void*)startLabel+2039)
+#define ST_v468	((void*)startLabel+2074)
+#define ST_v466	((void*)startLabel+2105)
+#define ST_v456	((void*)startLabel+2136)
+#define ST_v499	((void*)startLabel+2169)
+#define ST_v497	((void*)startLabel+2193)
+#define ST_v495	((void*)startLabel+2220)
+#define ST_v501	((void*)startLabel+2247)
+#define ST_v491	((void*)startLabel+2272)
+#define ST_v493	((void*)startLabel+2299)
+#define ST_v487	((void*)startLabel+2327)
+#define ST_v489	((void*)startLabel+2354)
+#define ST_v481	((void*)startLabel+2382)
+#define ST_v485	((void*)startLabel+2415)
+#define ST_v483	((void*)startLabel+2444)
+#define ST_v503	((void*)startLabel+2473)
+#define ST_v475	((void*)startLabel+2499)
+#define ST_v479	((void*)startLabel+2530)
+#define ST_v470	((void*)startLabel+2565)
+#define ST_v472	((void*)startLabel+2601)
+#define ST_v477	((void*)startLabel+2649)
 extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46intToAddr(void);
-extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46addrToInt(void);
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46Num_46Prelude_46Int_46_43[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46enumFromThenTo[];
 extern Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46enumFromTo[];
-extern Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46enumFromThen[];
-extern Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46enumFrom[];
-extern Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46succ[];
-extern Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46pred[];
-extern Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46showString[];
 extern Node FN_NHC_46Internal_46_95apply1[];
 extern Node FN_Numeric_46showHex[];
 extern Node CF_Prelude_46Integral_46Prelude_46Int[];
 extern Node FN_Prelude_46_46[];
 extern Node TMSUB_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46show[];
 extern Node CF_Prelude_46Show_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46showsType[];
-extern Node CF_Prelude_46Show_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46showList[];
-extern Node CF_Prelude_46Show_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46Ord_46Prelude_46Int_46compare[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46min[];
 extern Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46max[];
-extern Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46_62[];
-extern Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46_62_61[];
-extern Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46_60[];
-extern Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46_60_61[];
-extern Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46_95_46_47_61[];
 extern Node CF_Prelude_46Eq_46NHC_46FFI_46Addr[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v444)
+, useLabel(CT_v447)
 ,};
 Node FN_NHC_46FFI_46intToAddr[] = {
   useLabel(TM_NHC_46FFI)
@@ -146,16 +106,16 @@ Node FN_NHC_46FFI_46intToAddr[] = {
 , useLabel(FR_NHC_46FFI_46intToAddr)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 140021
-, useLabel(ST_v443)
-,	/* CT_v444: (byte 0) */
+, 140001
+, useLabel(ST_v446)
+,	/* CT_v447: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46intToAddr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46intToAddr),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v446)
+, useLabel(CT_v449)
 ,};
 Node FN_NHC_46FFI_46addrToInt[] = {
   useLabel(TM_NHC_46FFI)
@@ -163,9 +123,9 @@ Node FN_NHC_46FFI_46addrToInt[] = {
 , useLabel(FR_NHC_46FFI_46addrToInt)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 130021
-, useLabel(ST_v445)
-,	/* CT_v446: (byte 0) */
+, 130001
+, useLabel(ST_v448)
+,	/* CT_v449: (byte 0) */
   HW(0,1)
 , 0
 ,};
@@ -173,7 +133,7 @@ Node F0_NHC_46FFI_46addrToInt[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46addrToInt),1)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v448)
+, useLabel(CT_v451)
 ,};
 Node FN_NHC_46FFI_46plusAddr[] = {
   useLabel(TM_NHC_46FFI)
@@ -183,8 +143,8 @@ Node FN_NHC_46FFI_46plusAddr[] = {
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 320001
-, useLabel(ST_v447)
-,	/* CT_v448: (byte 0) */
+, useLabel(ST_v450)
+,	/* CT_v451: (byte 0) */
   HW(3,2)
 , 0
 ,};
@@ -194,7 +154,7 @@ Node F0_NHC_46FFI_46plusAddr[] = {
 , VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_43))
 , VAPTAG(useLabel(FN_NHC_46FFI_46intToAddr))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v450)
+, useLabel(CT_v453)
 ,};
 Node FN_NHC_46FFI_46nullAddr[] = {
   useLabel(TM_NHC_46FFI)
@@ -202,8 +162,8 @@ Node FN_NHC_46FFI_46nullAddr[] = {
 , bytes2word(0,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 310001
-, useLabel(ST_v449)
-,	/* CT_v450: (byte 0) */
+, useLabel(ST_v452)
+,	/* CT_v453: (byte 0) */
   HW(1,0)
 , 0
 ,};
@@ -211,7 +171,7 @@ Node CF_NHC_46FFI_46nullAddr[] = {
   VAPTAG(useLabel(FN_NHC_46FFI_46nullAddr))
 , VAPTAG(useLabel(FN_NHC_46FFI_46intToAddr))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v452)
+, useLabel(CT_v455)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46fromEnum[] = {
   useLabel(TM_NHC_46FFI)
@@ -219,8 +179,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46fromEnum[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 250003
-, useLabel(ST_v451)
-,	/* CT_v452: (byte 0) */
+, useLabel(ST_v454)
+,	/* CT_v455: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -228,7 +188,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46fromEnum[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46NHC_46FFI_46Addr_46fromEnum),1)
 , VAPTAG(useLabel(FN_NHC_46FFI_46addrToInt))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v454)
+, useLabel(CT_v457)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46toEnum[] = {
   useLabel(TM_NHC_46FFI)
@@ -236,8 +196,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46toEnum[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 240003
-, useLabel(ST_v453)
-,	/* CT_v454: (byte 0) */
+, useLabel(ST_v456)
+,	/* CT_v457: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -246,7 +206,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46toEnum[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46intToAddr))
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v456)
+, useLabel(CT_v459)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThenTo[] = {
   useLabel(TM_NHC_46FFI)
@@ -255,8 +215,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThenTo[] = {
 , bytes2word(3,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 230010
-, useLabel(ST_v455)
-,	/* CT_v456: (byte 0) */
+, useLabel(ST_v458)
+,	/* CT_v459: (byte 0) */
   HW(2,3)
 , 0
 ,};
@@ -266,7 +226,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThenTo[] = {
 , useLabel(CF_Prelude_46Enum_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v458)
+, useLabel(CT_v461)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromTo[] = {
   useLabel(TM_NHC_46FFI)
@@ -274,8 +234,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromTo[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 230010
-, useLabel(ST_v457)
-,	/* CT_v458: (byte 0) */
+, useLabel(ST_v460)
+,	/* CT_v461: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -285,7 +245,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromTo[] = {
 , useLabel(CF_Prelude_46Enum_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v460)
+, useLabel(CT_v463)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThen[] = {
   useLabel(TM_NHC_46FFI)
@@ -293,8 +253,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThen[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 230010
-, useLabel(ST_v459)
-,	/* CT_v460: (byte 0) */
+, useLabel(ST_v462)
+,	/* CT_v463: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -303,7 +263,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThen[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46enumFromThen))
 , useLabel(CF_Prelude_46Enum_46NHC_46FFI_46Addr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v462)
+, useLabel(CT_v465)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFrom[] = {
   useLabel(TM_NHC_46FFI)
@@ -311,8 +271,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFrom[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 230010
-, useLabel(ST_v461)
-,	/* CT_v462: (byte 0) */
+, useLabel(ST_v464)
+,	/* CT_v465: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -321,7 +281,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFrom[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46enumFrom))
 , useLabel(CF_Prelude_46Enum_46NHC_46FFI_46Addr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v464)
+, useLabel(CT_v467)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46succ[] = {
   useLabel(TM_NHC_46FFI)
@@ -329,8 +289,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46succ[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 230010
-, useLabel(ST_v463)
-,	/* CT_v464: (byte 0) */
+, useLabel(ST_v466)
+,	/* CT_v467: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -339,7 +299,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46succ[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46succ))
 , useLabel(CF_Prelude_46Enum_46NHC_46FFI_46Addr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v466)
+, useLabel(CT_v469)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46pred[] = {
   useLabel(TM_NHC_46FFI)
@@ -347,8 +307,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr_46pred[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 230010
-, useLabel(ST_v465)
-,	/* CT_v466: (byte 0) */
+, useLabel(ST_v468)
+,	/* CT_v469: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -358,7 +318,7 @@ Node F0_Prelude_46Enum_46NHC_46FFI_46Addr_46pred[] = {
 , useLabel(CF_Prelude_46Enum_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v468)
+, useLabel(CT_v471)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46showsPrec[] = {
   useLabel(TM_NHC_46FFI)
@@ -372,38 +332,38 @@ Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46showsPrec[] = {
 , bytes2word(5,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 220003
-, useLabel(ST_v467)
-,	/* CT_v468: (byte 0) */
+, useLabel(ST_v470)
+,	/* CT_v471: (byte 0) */
   HW(7,2)
 , 0
 ,};
 Node F0_Prelude_46Show_46NHC_46FFI_46Addr_46showsPrec[] = {
   CAPTAG(useLabel(FN_Prelude_46Show_46NHC_46FFI_46Addr_46showsPrec),2)
 , VAPTAG(useLabel(FN_Prelude_46showString))
-, VAPTAG(useLabel(FN_LAMBDA441))
+, VAPTAG(useLabel(FN_LAMBDA444))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
 , VAPTAG(useLabel(FN_Numeric_46showHex))
 , useLabel(CF_Prelude_46Integral_46Prelude_46Int)
 , VAPTAG(useLabel(FN_NHC_46FFI_46addrToInt))
 , VAPTAG(useLabel(FN_Prelude_46_46))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v471)
-,	/* FN_LAMBDA441: (byte 0) */
+, useLabel(CT_v474)
+,	/* FN_LAMBDA444: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v470)
+, useLabel(ST_v473)
 , 220030
-, useLabel(ST_v469)
-,	/* CT_v471: (byte 0) */
+, useLabel(ST_v472)
+,	/* CT_v474: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA441: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA441))
+,	/* CF_LAMBDA444: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA444))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v473)
+, useLabel(CT_v476)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46show[] = {
   useLabel(TM_NHC_46FFI)
@@ -411,8 +371,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46show[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 210010
-, useLabel(ST_v472)
-,	/* CT_v473: (byte 0) */
+, useLabel(ST_v475)
+,	/* CT_v476: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -421,7 +381,7 @@ Node F0_Prelude_46Show_46NHC_46FFI_46Addr_46show[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46show))
 , useLabel(CF_Prelude_46Show_46NHC_46FFI_46Addr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v475)
+, useLabel(CT_v478)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46showsType[] = {
   useLabel(TM_NHC_46FFI)
@@ -429,8 +389,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46showsType[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 210010
-, useLabel(ST_v474)
-,	/* CT_v475: (byte 0) */
+, useLabel(ST_v477)
+,	/* CT_v478: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -439,7 +399,7 @@ Node F0_Prelude_46Show_46NHC_46FFI_46Addr_46showsType[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46showsType))
 , useLabel(CF_Prelude_46Show_46NHC_46FFI_46Addr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v477)
+, useLabel(CT_v480)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46showList[] = {
   useLabel(TM_NHC_46FFI)
@@ -447,8 +407,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46Addr_46showList[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 210010
-, useLabel(ST_v476)
-,	/* CT_v477: (byte 0) */
+, useLabel(ST_v479)
+,	/* CT_v480: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -458,7 +418,7 @@ Node F0_Prelude_46Show_46NHC_46FFI_46Addr_46showList[] = {
 , useLabel(CF_Prelude_46Show_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v479)
+, useLabel(CT_v482)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46compare[] = {
   useLabel(TM_NHC_46FFI)
@@ -468,8 +428,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46compare[] = {
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 200003
-, useLabel(ST_v478)
-,	/* CT_v479: (byte 0) */
+, useLabel(ST_v481)
+,	/* CT_v482: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -479,7 +439,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46compare[] = {
 , VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Int_46compare))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v481)
+, useLabel(CT_v484)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46min[] = {
   useLabel(TM_NHC_46FFI)
@@ -487,8 +447,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46min[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190010
-, useLabel(ST_v480)
-,	/* CT_v481: (byte 0) */
+, useLabel(ST_v483)
+,	/* CT_v484: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -498,7 +458,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46min[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v483)
+, useLabel(CT_v486)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46max[] = {
   useLabel(TM_NHC_46FFI)
@@ -506,8 +466,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46max[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190010
-, useLabel(ST_v482)
-,	/* CT_v483: (byte 0) */
+, useLabel(ST_v485)
+,	/* CT_v486: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -517,7 +477,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46max[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v485)
+, useLabel(CT_v488)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_62[] = {
   useLabel(TM_NHC_46FFI)
@@ -525,8 +485,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_62[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190010
-, useLabel(ST_v484)
-,	/* CT_v485: (byte 0) */
+, useLabel(ST_v487)
+,	/* CT_v488: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -536,7 +496,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46_62[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v487)
+, useLabel(CT_v490)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_62_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -544,8 +504,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_62_61[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190010
-, useLabel(ST_v486)
-,	/* CT_v487: (byte 0) */
+, useLabel(ST_v489)
+,	/* CT_v490: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -555,7 +515,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46_62_61[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v489)
+, useLabel(CT_v492)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_60[] = {
   useLabel(TM_NHC_46FFI)
@@ -563,8 +523,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_60[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190010
-, useLabel(ST_v488)
-,	/* CT_v489: (byte 0) */
+, useLabel(ST_v491)
+,	/* CT_v492: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -574,7 +534,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46_60[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v491)
+, useLabel(CT_v494)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_60_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -582,8 +542,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr_46_60_61[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190010
-, useLabel(ST_v490)
-,	/* CT_v491: (byte 0) */
+, useLabel(ST_v493)
+,	/* CT_v494: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -593,7 +553,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46Addr_46_60_61[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46Addr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v493)
+, useLabel(CT_v496)
 ,};
 Node FN_Prelude_46Eq_46NHC_46FFI_46Addr_46_61_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -603,9 +563,9 @@ Node FN_Prelude_46Eq_46NHC_46FFI_46Addr_46_61_61[] = {
 , bytes2word(ZAP_ARG_I1,EVAL,EQ_W,RETURN)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
-, 180005
-, useLabel(ST_v492)
-,	/* CT_v493: (byte 0) */
+, 180003
+, useLabel(ST_v495)
+,	/* CT_v496: (byte 0) */
   HW(1,2)
 , 0
 ,};
@@ -614,7 +574,7 @@ Node F0_Prelude_46Eq_46NHC_46FFI_46Addr_46_61_61[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46addrToInt))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v495)
+, useLabel(CT_v498)
 ,};
 Node FN_Prelude_46Eq_46NHC_46FFI_46Addr_46_47_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -622,8 +582,8 @@ Node FN_Prelude_46Eq_46NHC_46FFI_46Addr_46_47_61[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 170010
-, useLabel(ST_v494)
-,	/* CT_v495: (byte 0) */
+, useLabel(ST_v497)
+,	/* CT_v498: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -632,7 +592,7 @@ Node F0_Prelude_46Eq_46NHC_46FFI_46Addr_46_47_61[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46_47_61))
 , useLabel(CF_Prelude_46Eq_46NHC_46FFI_46Addr)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v497)
+, useLabel(CT_v500)
 ,};
 Node FN_Prelude_46Eq_46NHC_46FFI_46Addr[] = {
   useLabel(TM_NHC_46FFI)
@@ -642,8 +602,8 @@ Node FN_Prelude_46Eq_46NHC_46FFI_46Addr[] = {
 , 0
 , CONSTR(0,2,0)
 , 170010
-, useLabel(ST_v496)
-,	/* CT_v497: (byte 0) */
+, useLabel(ST_v499)
+,	/* CT_v500: (byte 0) */
   HW(2,0)
 , 0
 ,};
@@ -652,7 +612,7 @@ Node CF_Prelude_46Eq_46NHC_46FFI_46Addr[] = {
 , useLabel(F0_Prelude_46Eq_46NHC_46FFI_46Addr_46_47_61)
 , useLabel(F0_Prelude_46Eq_46NHC_46FFI_46Addr_46_61_61)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v499)
+, useLabel(CT_v502)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46Addr[] = {
   useLabel(TM_NHC_46FFI)
@@ -665,8 +625,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46Addr[] = {
 , 0
 , CONSTR(0,8,0)
 , 190010
-, useLabel(ST_v498)
-,	/* CT_v499: (byte 0) */
+, useLabel(ST_v501)
+,	/* CT_v502: (byte 0) */
   HW(8,0)
 , 0
 ,};
@@ -681,7 +641,7 @@ Node CF_Prelude_46Ord_46NHC_46FFI_46Addr[] = {
 , useLabel(F0_Prelude_46Ord_46NHC_46FFI_46Addr_46min)
 , useLabel(F0_Prelude_46Ord_46NHC_46FFI_46Addr_46max)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v501)
+, useLabel(CT_v504)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46Addr[] = {
   useLabel(TM_NHC_46FFI)
@@ -692,8 +652,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46Addr[] = {
 , 0
 , CONSTR(0,4,0)
 , 210010
-, useLabel(ST_v500)
-,	/* CT_v501: (byte 0) */
+, useLabel(ST_v503)
+,	/* CT_v504: (byte 0) */
   HW(4,0)
 , 0
 ,};
@@ -704,7 +664,7 @@ Node CF_Prelude_46Show_46NHC_46FFI_46Addr[] = {
 , useLabel(F0_Prelude_46Show_46NHC_46FFI_46Addr_46showList)
 , useLabel(F0_Prelude_46Show_46NHC_46FFI_46Addr_46show)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v503)
+, useLabel(CT_v506)
 ,};
 Node FN_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
   useLabel(TM_NHC_46FFI)
@@ -717,8 +677,8 @@ Node FN_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , 0
 , CONSTR(0,8,0)
 , 230010
-, useLabel(ST_v502)
-,	/* CT_v503: (byte 0) */
+, useLabel(ST_v505)
+,	/* CT_v506: (byte 0) */
   HW(8,0)
 , 0
 ,};
@@ -732,37 +692,37 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , useLabel(F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThen)
 , useLabel(F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromTo)
 , useLabel(F0_Prelude_46Enum_46NHC_46FFI_46Addr_46enumFromThenTo)
-,	/* ST_v470: (byte 0) */
- 	/* ST_v445: (byte 3) */
+,	/* ST_v473: (byte 0) */
+ 	/* ST_v448: (byte 3) */
   bytes2word(48,120,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,97)
 , bytes2word(100,100,114,84)
 , bytes2word(111,73,110,116)
-,	/* ST_v443: (byte 1) */
+,	/* ST_v446: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,105,110,116)
 , bytes2word(84,111,65,100)
-,	/* ST_v449: (byte 3) */
+,	/* ST_v452: (byte 3) */
   bytes2word(100,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,110)
 , bytes2word(117,108,108,65)
-,	/* ST_v447: (byte 4) */
+,	/* ST_v450: (byte 4) */
   bytes2word(100,100,114,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(112,108,117,115)
 , bytes2word(65,100,100,114)
-,	/* ST_v502: (byte 1) */
+,	/* ST_v505: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
 , bytes2word(109,46,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,65,100)
-,	/* ST_v461: (byte 3) */
+,	/* ST_v464: (byte 3) */
   bytes2word(100,114,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,69)
@@ -772,7 +732,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(65,100,100,114)
 , bytes2word(46,101,110,117)
 , bytes2word(109,70,114,111)
-,	/* ST_v459: (byte 2) */
+,	/* ST_v462: (byte 2) */
   bytes2word(109,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,110)
@@ -783,7 +743,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(101,110,117,109)
 , bytes2word(70,114,111,109)
 , bytes2word(84,104,101,110)
-,	/* ST_v455: (byte 1) */
+,	/* ST_v458: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
@@ -794,7 +754,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(110,117,109,70)
 , bytes2word(114,111,109,84)
 , bytes2word(104,101,110,84)
-,	/* ST_v457: (byte 2) */
+,	/* ST_v460: (byte 2) */
   bytes2word(111,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,110)
@@ -804,7 +764,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(100,100,114,46)
 , bytes2word(101,110,117,109)
 , bytes2word(70,114,111,109)
-,	/* ST_v451: (byte 3) */
+,	/* ST_v454: (byte 3) */
   bytes2word(84,111,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,69)
@@ -814,7 +774,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(65,100,100,114)
 , bytes2word(46,102,114,111)
 , bytes2word(109,69,110,117)
-,	/* ST_v465: (byte 2) */
+,	/* ST_v468: (byte 2) */
   bytes2word(109,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,110)
@@ -823,7 +783,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(70,73,46,65)
 , bytes2word(100,100,114,46)
 , bytes2word(112,114,101,100)
-,	/* ST_v463: (byte 1) */
+,	/* ST_v466: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
@@ -831,7 +791,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,65,100)
 , bytes2word(100,114,46,115)
-,	/* ST_v453: (byte 4) */
+,	/* ST_v456: (byte 4) */
   bytes2word(117,99,99,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -841,21 +801,21 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(46,65,100,100)
 , bytes2word(114,46,116,111)
 , bytes2word(69,110,117,109)
-,	/* ST_v496: (byte 1) */
+,	/* ST_v499: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,113,46)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(65,100,100,114)
-,	/* ST_v494: (byte 1) */
+,	/* ST_v497: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,113,46)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(65,100,100,114)
-,	/* ST_v492: (byte 4) */
+,	/* ST_v495: (byte 4) */
   bytes2word(46,47,61,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -863,14 +823,14 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,65)
 , bytes2word(100,100,114,46)
-,	/* ST_v498: (byte 3) */
+,	/* ST_v501: (byte 3) */
   bytes2word(61,61,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
 , bytes2word(114,100,46,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,65)
-,	/* ST_v488: (byte 4) */
+,	/* ST_v491: (byte 4) */
   bytes2word(100,100,114,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -878,7 +838,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(65,100,100,114)
-,	/* ST_v490: (byte 3) */
+,	/* ST_v493: (byte 3) */
   bytes2word(46,60,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
@@ -886,7 +846,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,65)
 , bytes2word(100,100,114,46)
-,	/* ST_v484: (byte 3) */
+,	/* ST_v487: (byte 3) */
   bytes2word(60,61,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
@@ -894,7 +854,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,65)
 , bytes2word(100,100,114,46)
-,	/* ST_v486: (byte 2) */
+,	/* ST_v489: (byte 2) */
   bytes2word(62,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,79,114)
@@ -902,7 +862,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,65,100)
 , bytes2word(100,114,46,62)
-,	/* ST_v478: (byte 2) */
+,	/* ST_v481: (byte 2) */
   bytes2word(61,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,79,114)
@@ -911,7 +871,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(73,46,65,100)
 , bytes2word(100,114,46,99)
 , bytes2word(111,109,112,97)
-,	/* ST_v482: (byte 3) */
+,	/* ST_v485: (byte 3) */
   bytes2word(114,101,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
@@ -919,7 +879,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,65)
 , bytes2word(100,100,114,46)
-,	/* ST_v480: (byte 4) */
+,	/* ST_v483: (byte 4) */
   bytes2word(109,97,120,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -928,14 +888,14 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(70,70,73,46)
 , bytes2word(65,100,100,114)
 , bytes2word(46,109,105,110)
-,	/* ST_v500: (byte 1) */
+,	/* ST_v503: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,83,104,111)
 , bytes2word(119,46,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,65,100)
-,	/* ST_v472: (byte 3) */
+,	/* ST_v475: (byte 3) */
   bytes2word(100,114,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,83)
@@ -944,7 +904,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(70,70,73,46)
 , bytes2word(65,100,100,114)
 , bytes2word(46,115,104,111)
-,	/* ST_v476: (byte 2) */
+,	/* ST_v479: (byte 2) */
   bytes2word(119,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,83,104)
@@ -954,7 +914,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(100,100,114,46)
 , bytes2word(115,104,111,119)
 , bytes2word(76,105,115,116)
-,	/* ST_v467: (byte 1) */
+,	/* ST_v470: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,83,104,111)
@@ -964,7 +924,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(100,114,46,115)
 , bytes2word(104,111,119,115)
 , bytes2word(80,114,101,99)
-,	/* ST_v469: (byte 1) */
+,	/* ST_v472: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,83,104,111)
@@ -975,17 +935,19 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 , bytes2word(104,111,119,115)
 , bytes2word(80,114,101,99)
 , bytes2word(58,50,50,58)
-,	/* ST_v474: (byte 3) */
-  bytes2word(51,48,0,80)
-, bytes2word(114,101,108,117)
-, bytes2word(100,101,46,83)
-, bytes2word(104,111,119,46)
-, bytes2word(78,72,67,46)
-, bytes2word(70,70,73,46)
-, bytes2word(65,100,100,114)
-, bytes2word(46,115,104,111)
-, bytes2word(119,115,84,121)
-, bytes2word(112,101,0,0)
+, bytes2word(51,48,45,50)
+, bytes2word(50,58,51,51)
+,	/* ST_v477: (byte 1) */
+  bytes2word(0,80,114,101)
+, bytes2word(108,117,100,101)
+, bytes2word(46,83,104,111)
+, bytes2word(119,46,78,72)
+, bytes2word(67,46,70,70)
+, bytes2word(73,46,65,100)
+, bytes2word(100,114,46,115)
+, bytes2word(104,111,119,115)
+, bytes2word(84,121,112,101)
+, bytes2word(0,0,0,0)
 ,};
 
 #include <haskell2c.h>
@@ -993,7 +955,7 @@ Node CF_Prelude_46Enum_46NHC_46FFI_46Addr[] = {
 
 /* foreign import cast "intToAddr" NHC.FFI.intToAddr 1 :: Prelude.Int -> FFI.Addr */
 #ifdef PROFILE
-static SInfo pf_intToAddr = {"NHC.FFI","NHC.FFI.intToAddr","FFI.Addr"};
+static SInfo pf_NHC_46FFI_46intToAddr = {"NHC.FFI","NHC.FFI.intToAddr","FFI.Addr"};
 #endif
 C_HEADER(FR_NHC_46FFI_46intToAddr) {
   NodePtr nodeptr;
@@ -1006,13 +968,13 @@ C_HEADER(FR_NHC_46FFI_46intToAddr) {
   result = (void*)(arg1);
 
   nodeptr = nhc_mkInt((int)result);
-  INIT_PROFINFO(nodeptr,&pf_intToAddr);
+  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46intToAddr);
   C_RETURN(nodeptr);
 }
 
 /* foreign import cast "addrToInt" NHC.FFI.addrToInt 1 :: FFI.Addr -> Prelude.Int */
 #ifdef PROFILE
-static SInfo pf_addrToInt = {"NHC.FFI","NHC.FFI.addrToInt","Prelude.Int"};
+static SInfo pf_NHC_46FFI_46addrToInt = {"NHC.FFI","NHC.FFI.addrToInt","Prelude.Int"};
 #endif
 C_HEADER(FR_NHC_46FFI_46addrToInt) {
   NodePtr nodeptr;
@@ -1025,6 +987,6 @@ C_HEADER(FR_NHC_46FFI_46addrToInt) {
   result = (HsInt)(arg1);
 
   nodeptr = nhc_mkInt(result);
-  INIT_PROFINFO(nodeptr,&pf_addrToInt);
+  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46addrToInt);
   C_RETURN(nodeptr);
 }
