@@ -1,3 +1,4 @@
+{-# OPTIONS_COMPILE -cpp #-}
 module NHC.FFI 
   -- Integral types, instances of: Eq, Ord, Num, Read, Show, Enum,
   -- Storable, Bounded, Real, Integral
@@ -12,21 +13,26 @@ module NHC.FFI
 
   ) where
 
-import Int
-import Word
+import NonStdUnsafeCoerce
+import Storable	( Storable(..) )
+-- import Data.Bits( Bits(..) )
+-- import NHC.SizedTypes
+import Monad	( liftM )
+import Ptr	( castPtr )
 import CTypes
 
+#include "CTypes.h"
+
 -- So far, we just make a best guess at these types for most 32-bit machines.
 -- Should really be auto-configured.
 
-newtype CPtrdiff   = CPtrdiff CInt	-- ??
-newtype CWchar     = CWchar CInt	-- ??
-newtype CSigAtomic = CSigAtomic CInt	-- ??
+INTEGRAL_TYPE(CPtrdiff,CInt)
+INTEGRAL_TYPE(CWchar,CInt)
+INTEGRAL_TYPE(CSigAtomic,CInt)
+INTEGRAL_TYPE(CSize,CInt)
 
--- Should be newtypes perhaps?
-type CSize      = CInt		-- size_t
-type CClock     = CUInt		-- clock_t
-type CTime      = CUInt		-- time_t
+ARITHMETIC_TYPE(CClock,CUInt)
+ARITHMETIC_TYPE(CTime,CUInt)
 
 -- Not sure what these are for??
 data CFile   = CFile		-- ??
