@@ -2,85 +2,90 @@
 #include "runtime.h"
 
 #define FN_NHC_46FFI_46_95free_35	((void*)startLabel+8)
-#define CT_v526	((void*)startLabel+36)
+#define CT_v575	((void*)startLabel+36)
 #define F0_NHC_46FFI_46_95free_35	((void*)startLabel+44)
 #define FN_NHC_46FFI_46_95free	((void*)startLabel+56)
-#define CT_v528	((void*)startLabel+80)
+#define CT_v577	((void*)startLabel+80)
 #define CF_NHC_46FFI_46_95free	((void*)startLabel+88)
 #define FN_NHC_46FFI_46_95realloc_35	((void*)startLabel+112)
-#define CT_v530	((void*)startLabel+144)
+#define CT_v579	((void*)startLabel+144)
 #define F0_NHC_46FFI_46_95realloc_35	((void*)startLabel+152)
 #define FN_NHC_46FFI_46_95realloc	((void*)startLabel+164)
-#define CT_v532	((void*)startLabel+188)
+#define CT_v581	((void*)startLabel+188)
 #define CF_NHC_46FFI_46_95realloc	((void*)startLabel+196)
 #define FN_NHC_46FFI_46_95malloc_35	((void*)startLabel+216)
-#define CT_v534	((void*)startLabel+244)
+#define CT_v583	((void*)startLabel+244)
 #define F0_NHC_46FFI_46_95malloc_35	((void*)startLabel+252)
 #define FN_NHC_46FFI_46_95malloc	((void*)startLabel+264)
-#define CT_v536	((void*)startLabel+288)
+#define CT_v585	((void*)startLabel+288)
 #define CF_NHC_46FFI_46_95malloc	((void*)startLabel+296)
 #define FN_NHC_46FFI_46failWhenNULL	((void*)startLabel+320)
-#define CT_v538	((void*)startLabel+348)
+#define CT_v587	((void*)startLabel+348)
 #define F0_NHC_46FFI_46failWhenNULL	((void*)startLabel+356)
-#define FN_LAMBDA521	((void*)startLabel+380)
-#define CT_v540	((void*)startLabel+456)
-#define F0_LAMBDA521	((void*)startLabel+464)
-#define FN_LAMBDA520	((void*)startLabel+516)
-#define CT_v543	((void*)startLabel+548)
-#define CF_LAMBDA520	((void*)startLabel+556)
-#define CT_v545	((void*)startLabel+592)
-#define CT_v547	((void*)startLabel+668)
-#define FN_LAMBDA522	((void*)startLabel+720)
-#define CT_v550	((void*)startLabel+752)
-#define CF_LAMBDA522	((void*)startLabel+760)
-#define CT_v552	((void*)startLabel+820)
-#define FN_LAMBDA523	((void*)startLabel+868)
-#define CT_v555	((void*)startLabel+900)
-#define CF_LAMBDA523	((void*)startLabel+908)
-#define CT_v557	((void*)startLabel+948)
-#define CT_v559	((void*)startLabel+1004)
-#define FN_NHC_46FFI_46Prelude_46362_46doAlloca	((void*)startLabel+1036)
-#define CT_v561	((void*)startLabel+1068)
-#define F0_NHC_46FFI_46Prelude_46362_46doAlloca	((void*)startLabel+1076)
-#define CT_v563	((void*)startLabel+1124)
-#define FN_NHC_46FFI_46Prelude_46359_46doMalloc	((void*)startLabel+1156)
-#define CT_v565	((void*)startLabel+1188)
-#define F0_NHC_46FFI_46Prelude_46359_46doMalloc	((void*)startLabel+1196)
-#define ST_v542	((void*)startLabel+1212)
-#define ST_v527	((void*)startLabel+1227)
-#define ST_v525	((void*)startLabel+1241)
-#define ST_v535	((void*)startLabel+1256)
-#define ST_v533	((void*)startLabel+1272)
-#define ST_v531	((void*)startLabel+1289)
-#define ST_v529	((void*)startLabel+1306)
-#define ST_v558	((void*)startLabel+1324)
-#define ST_v560	((void*)startLabel+1339)
-#define ST_v556	((void*)startLabel+1359)
-#define ST_v537	((void*)startLabel+1379)
-#define ST_v539	((void*)startLabel+1400)
-#define ST_v541	((void*)startLabel+1427)
-#define ST_v544	((void*)startLabel+1454)
-#define ST_v562	((void*)startLabel+1467)
-#define ST_v564	((void*)startLabel+1482)
-#define ST_v551	((void*)startLabel+1502)
-#define ST_v553	((void*)startLabel+1522)
-#define ST_v546	((void*)startLabel+1548)
-#define ST_v548	((void*)startLabel+1569)
-#define ST_v554	((void*)startLabel+1596)
-#define ST_v549	((void*)startLabel+1603)
+#define FN_LAMBDA569	((void*)startLabel+380)
+#define CT_v589	((void*)startLabel+456)
+#define F0_LAMBDA569	((void*)startLabel+464)
+#define FN_LAMBDA568	((void*)startLabel+516)
+#define CT_v592	((void*)startLabel+548)
+#define CF_LAMBDA568	((void*)startLabel+556)
+#define CT_v594	((void*)startLabel+596)
+#define CT_v596	((void*)startLabel+640)
+#define CT_v598	((void*)startLabel+716)
+#define FN_LAMBDA570	((void*)startLabel+768)
+#define CT_v601	((void*)startLabel+800)
+#define CF_LAMBDA570	((void*)startLabel+808)
+#define CT_v603	((void*)startLabel+852)
+#define FN_NHC_46FFI_46Prelude_46375_46doRealloc	((void*)startLabel+884)
+#define CT_v605	((void*)startLabel+944)
+#define F0_NHC_46FFI_46Prelude_46375_46doRealloc	((void*)startLabel+952)
+#define FN_LAMBDA571	((void*)startLabel+1000)
+#define CT_v607	((void*)startLabel+1032)
+#define CF_LAMBDA571	((void*)startLabel+1040)
+#define CT_v609	((void*)startLabel+1100)
+#define FN_LAMBDA572	((void*)startLabel+1148)
+#define CT_v612	((void*)startLabel+1180)
+#define CF_LAMBDA572	((void*)startLabel+1188)
+#define CT_v614	((void*)startLabel+1228)
+#define CT_v616	((void*)startLabel+1284)
+#define FN_NHC_46FFI_46Prelude_46371_46doAlloca	((void*)startLabel+1316)
+#define CT_v618	((void*)startLabel+1348)
+#define F0_NHC_46FFI_46Prelude_46371_46doAlloca	((void*)startLabel+1356)
+#define CT_v620	((void*)startLabel+1404)
+#define FN_NHC_46FFI_46Prelude_46368_46doMalloc	((void*)startLabel+1436)
+#define CT_v622	((void*)startLabel+1468)
+#define F0_NHC_46FFI_46Prelude_46368_46doMalloc	((void*)startLabel+1476)
+#define ST_v591	((void*)startLabel+1492)
+#define ST_v576	((void*)startLabel+1507)
+#define ST_v574	((void*)startLabel+1521)
+#define ST_v584	((void*)startLabel+1536)
+#define ST_v582	((void*)startLabel+1552)
+#define ST_v580	((void*)startLabel+1569)
+#define ST_v578	((void*)startLabel+1586)
+#define ST_v615	((void*)startLabel+1604)
+#define ST_v617	((void*)startLabel+1619)
+#define ST_v613	((void*)startLabel+1645)
+#define ST_v586	((void*)startLabel+1665)
+#define ST_v588	((void*)startLabel+1686)
+#define ST_v590	((void*)startLabel+1713)
+#define ST_v593	((void*)startLabel+1746)
+#define ST_v595	((void*)startLabel+1768)
+#define ST_v619	((void*)startLabel+1781)
+#define ST_v621	((void*)startLabel+1796)
+#define ST_v608	((void*)startLabel+1822)
+#define ST_v610	((void*)startLabel+1842)
+#define ST_v602	((void*)startLabel+1874)
+#define ST_v604	((void*)startLabel+1890)
+#define ST_v606	((void*)startLabel+1917)
+#define ST_v597	((void*)startLabel+1945)
+#define ST_v599	((void*)startLabel+1966)
+#define ST_v611	((void*)startLabel+1999)
+#define ST_v600	((void*)startLabel+2006)
 extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46_95free_35(void);
-extern Node TM_NHC_46FFI[];
 extern Node FN_NHC_46Internal_46_95mkIOok1[];
-extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46_95realloc_35(void);
-extern Node TM_NHC_46FFI[];
 extern Node FN_NHC_46Internal_46_95mkIOok2[];
-extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46_95malloc_35(void);
-extern Node TM_NHC_46FFI[];
-extern Node FN_NHC_46Internal_46_95mkIOok1[];
-extern Node TM_NHC_46FFI[];
 extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
 extern Node TMSUB_NHC_46FFI[];
 extern Node FN_Prelude_46Eq_46NHC_46FFI_46Ptr_46_61_61[];
@@ -92,60 +97,42 @@ extern Node FN_Monad_46when[];
 extern Node CF_Prelude_46Monad_46NHC_46Internal_46IO[];
 extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
 extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62[];
-extern Node TMSUB_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
+void FR_NHC_46FFI_46finalizerFree(void);
 extern Node FN_Prelude_46fromIntegral[];
 extern Node CF_Prelude_46Integral_46Prelude_46Int[];
-extern Node CF_Prelude_46Num_46NHC_46FFI_46CInt[];
+extern Node CF_Prelude_46Num_46NHC_46FFI_46CSize[];
 extern Node FN_NHC_46Internal_46_95apply1[];
 extern Node FN_NHC_46Internal_46_95apply2[];
-extern Node TMSUB_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
-extern Node FN_Prelude_46fromIntegral[];
-extern Node CF_Prelude_46Integral_46Prelude_46Int[];
-extern Node CF_Prelude_46Num_46NHC_46FFI_46CInt[];
-extern Node FN_NHC_46Internal_46_95apply1[];
-extern Node TMSUB_NHC_46FFI[];
-extern Node TM_NHC_46FFI[];
+extern Node CF_Prelude_46undefined[];
+extern Node FN_NHC_46FFI_46sizeOf[];
 extern Node FN_IO_46bracket[];
-extern Node TM_NHC_46FFI[];
-extern Node CF_Prelude_46undefined[];
-extern Node TMSUB_NHC_46FFI[];
-extern Node FN_NHC_46FFI_46sizeOf[];
-extern Node FN_NHC_46Internal_46_95apply1[];
-extern Node TM_NHC_46FFI[];
-extern Node CF_Prelude_46undefined[];
-extern Node TMSUB_NHC_46FFI[];
-extern Node FN_NHC_46FFI_46sizeOf[];
-extern Node FN_NHC_46Internal_46_95apply1[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v526)
+, useLabel(CT_v575)
 ,	/* FN_NHC_46FFI_46_95free_35: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
 , useLabel(FR_NHC_46FFI_46_95free_35)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 790039
-, useLabel(ST_v525)
-,	/* CT_v526: (byte 0) */
+, 950001
+, useLabel(ST_v574)
+,	/* CT_v575: (byte 0) */
   HW(0,1)
 , 0
 ,	/* F0_NHC_46FFI_46_95free_35: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46_95free_35),1)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v528)
+, useLabel(CT_v577)
 ,	/* FN_NHC_46FFI_46_95free: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 790039
-, useLabel(ST_v527)
-,	/* CT_v528: (byte 0) */
+, 950001
+, useLabel(ST_v576)
+,	/* CT_v577: (byte 0) */
   HW(2,0)
 , 0
 ,	/* CF_NHC_46FFI_46_95free: (byte 0) */
@@ -154,7 +141,7 @@ static Node startLabel[] = {
 , useLabel(F0_NHC_46FFI_46_95free_35)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v530)
+, useLabel(CT_v579)
 ,	/* FN_NHC_46FFI_46_95realloc_35: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
@@ -162,23 +149,23 @@ static Node startLabel[] = {
 , useLabel(FR_NHC_46FFI_46_95realloc_35)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 780039
-, useLabel(ST_v529)
-,	/* CT_v530: (byte 0) */
+, 930001
+, useLabel(ST_v578)
+,	/* CT_v579: (byte 0) */
   HW(0,2)
 , 0
 ,	/* F0_NHC_46FFI_46_95realloc_35: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46_95realloc_35),2)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v532)
+, useLabel(CT_v581)
 ,	/* FN_NHC_46FFI_46_95realloc: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 780039
-, useLabel(ST_v531)
-,	/* CT_v532: (byte 0) */
+, 930001
+, useLabel(ST_v580)
+,	/* CT_v581: (byte 0) */
   HW(2,0)
 , 0
 ,	/* CF_NHC_46FFI_46_95realloc: (byte 0) */
@@ -186,30 +173,30 @@ static Node startLabel[] = {
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
 , useLabel(F0_NHC_46FFI_46_95realloc_35)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v534)
+, useLabel(CT_v583)
 ,	/* FN_NHC_46FFI_46_95malloc_35: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
 , useLabel(FR_NHC_46FFI_46_95malloc_35)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 770039
-, useLabel(ST_v533)
-,	/* CT_v534: (byte 0) */
+, 920001
+, useLabel(ST_v582)
+,	/* CT_v583: (byte 0) */
   HW(0,1)
 , 0
 ,	/* F0_NHC_46FFI_46_95malloc_35: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46_95malloc_35),1)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v536)
+, useLabel(CT_v585)
 ,	/* FN_NHC_46FFI_46_95malloc: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 770039
-, useLabel(ST_v535)
-,	/* CT_v536: (byte 0) */
+, 920001
+, useLabel(ST_v584)
+,	/* CT_v585: (byte 0) */
   HW(2,0)
 , 0
 ,	/* CF_NHC_46FFI_46_95malloc: (byte 0) */
@@ -218,26 +205,26 @@ static Node startLabel[] = {
 , useLabel(F0_NHC_46FFI_46_95malloc_35)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v538)
+, useLabel(CT_v587)
 ,	/* FN_NHC_46FFI_46failWhenNULL: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_ARG,2)
 , bytes2word(HEAP_OFF_N1,4,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, 700001
-, useLabel(ST_v537)
-,	/* CT_v538: (byte 0) */
+, 860001
+, useLabel(ST_v586)
+,	/* CT_v587: (byte 0) */
   HW(2,2)
 , 0
 ,	/* F0_NHC_46FFI_46failWhenNULL: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46failWhenNULL),2)
-, CAPTAG(useLabel(FN_LAMBDA521),1)
+, CAPTAG(useLabel(FN_LAMBDA569),1)
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v540)
-,	/* FN_LAMBDA521: (byte 0) */
+, useLabel(CT_v589)
+,	/* FN_LAMBDA569: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,2)
 , bytes2word(HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
@@ -255,16 +242,16 @@ static Node startLabel[] = {
 , bytes2word(0,0,0,0)
 , CONSTR(12,0,0)
 , CONSTR(0,0,0)
-, 710012
-, useLabel(ST_v539)
-,	/* CT_v540: (byte 0) */
+, 870012
+, useLabel(ST_v588)
+,	/* CT_v589: (byte 0) */
   HW(10,2)
 , 0
-,	/* F0_LAMBDA521: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA521),2)
+,	/* F0_LAMBDA569: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA569),2)
 , VAPTAG(useLabel(FN_Prelude_46Eq_46NHC_46FFI_46Ptr_46_61_61))
 , useLabel(CF_NHC_46FFI_46nullPtr)
-, VAPTAG(useLabel(FN_LAMBDA520))
+, VAPTAG(useLabel(FN_LAMBDA568))
 , VAPTAG(useLabel(FN_Prelude_46_43_43))
 , VAPTAG(useLabel(FN_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46fromEnum))
 , VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
@@ -273,32 +260,49 @@ static Node startLabel[] = {
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v543)
-,	/* FN_LAMBDA520: (byte 0) */
+, useLabel(CT_v592)
+,	/* FN_LAMBDA568: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v542)
-, 730028
-, useLabel(ST_v541)
-,	/* CT_v543: (byte 0) */
+, useLabel(ST_v591)
+, 890028
+, useLabel(ST_v590)
+,	/* CT_v592: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA520: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA520))
+,	/* CF_LAMBDA568: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA568))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v545)
+, useLabel(CT_v594)
+,};
+Node FN_NHC_46FFI_46finalizerFree[] = {
+  useLabel(TM_NHC_46FFI)
+, bytes2word(PRIMITIVE,NOP,NOP,NOP)
+, useLabel(FR_NHC_46FFI_46finalizerFree)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, 790001
+, useLabel(ST_v593)
+,	/* CT_v594: (byte 0) */
+  HW(0,0)
+, 0
+,};
+Node CF_NHC_46FFI_46finalizerFree[] = {
+  VAPTAG(useLabel(FN_NHC_46FFI_46finalizerFree))
+, bytes2word(0,0,0,0)
+, useLabel(CT_v596)
 ,};
 Node FN_NHC_46FFI_46free[] = {
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDSTACK_I16,PUSH_CVAL_P1,3,RETURN_EVAL)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
-, 630001
-, useLabel(ST_v544)
-,	/* CT_v545: (byte 0) */
+, 750001
+, useLabel(ST_v595)
+,	/* CT_v596: (byte 0) */
   HW(1,0)
 , 0
 ,};
@@ -307,7 +311,7 @@ Node CF_NHC_46FFI_46free[] = {
 , useLabel(CF_NHC_46FFI_46_95free)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v547)
+, useLabel(CT_v598)
 ,};
 Node FN_NHC_46FFI_46reallocBytes[] = {
   useLabel(TM_NHC_46FFI)
@@ -320,40 +324,109 @@ Node FN_NHC_46FFI_46reallocBytes[] = {
 , bytes2word(10,HEAP_OFF_N1,13,HEAP_OFF_N1)
 , bytes2word(6,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, 570001
-, useLabel(ST_v546)
-,	/* CT_v547: (byte 0) */
+, 690001
+, useLabel(ST_v597)
+,	/* CT_v598: (byte 0) */
   HW(8,2)
 , 0
 ,};
 Node F0_NHC_46FFI_46reallocBytes[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46reallocBytes),2)
-, VAPTAG(useLabel(FN_LAMBDA522))
+, VAPTAG(useLabel(FN_LAMBDA570))
 , VAPTAG(useLabel(FN_NHC_46FFI_46_95realloc))
 , VAPTAG(useLabel(FN_Prelude_46fromIntegral))
 , useLabel(CF_Prelude_46Integral_46Prelude_46Int)
-, useLabel(CF_Prelude_46Num_46NHC_46FFI_46CInt)
+, useLabel(CF_Prelude_46Num_46NHC_46FFI_46CSize)
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
 , VAPTAG(useLabel(FN_NHC_46FFI_46failWhenNULL))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v550)
-,	/* FN_LAMBDA522: (byte 0) */
+, useLabel(CT_v601)
+,	/* FN_LAMBDA570: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v549)
-, 580016
-, useLabel(ST_v548)
-,	/* CT_v550: (byte 0) */
+, useLabel(ST_v600)
+, 700016
+, useLabel(ST_v599)
+,	/* CT_v601: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA522: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA522))
+,	/* CF_LAMBDA570: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA570))
+, bytes2word(0,0,2,0)
+, bytes2word(1,1,0,2)
+, useLabel(CT_v603)
+,};
+Node FN_NHC_46FFI_46realloc[] = {
+  useLabel(TM_NHC_46FFI)
+, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG_ARG)
+, bytes2word(2,1,HEAP_CVAL_I4,RETURN_EVAL)
+, bytes2word(ENDCODE,0,0,0)
+, bytes2word(0,0,0,0)
+, 600001
+, useLabel(ST_v602)
+,	/* CT_v603: (byte 0) */
+  HW(2,2)
+, 0
+,};
+Node F0_NHC_46FFI_46realloc[] = {
+  CAPTAG(useLabel(FN_NHC_46FFI_46realloc),2)
+, VAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46375_46doRealloc))
+, useLabel(CF_Prelude_46undefined)
+, bytes2word(3,0,2,1)
+, bytes2word(1,2,0,3)
+, useLabel(CT_v605)
+,	/* FN_NHC_46FFI_46Prelude_46375_46doRealloc: (byte 0) */
+  useLabel(TMSUB_NHC_46FFI)
+, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_CVAL_I5)
+, bytes2word(HEAP_CVAL_P1,6,HEAP_CVAL_P1,7)
+, bytes2word(HEAP_CVAL_P1,8,HEAP_ARG,2)
+, bytes2word(HEAP_CVAL_P1,9,HEAP_OFF_N1,3)
+, bytes2word(HEAP_ARG,3,HEAP_CVAL_P1,9)
+, bytes2word(HEAP_OFF_N1,9,HEAP_OFF_N1,5)
+, bytes2word(HEAP_CVAL_P1,10,HEAP_OFF_N1,13)
+, bytes2word(HEAP_ARG,1,HEAP_OFF_N1,6)
+, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,11,HEAP_OFF_N1)
+, bytes2word(18,HEAP_OFF_N1,6,RETURN_EVAL)
+, bytes2word(ENDCODE,0,0,0)
+, bytes2word(0,0,0,0)
+, 630005
+, useLabel(ST_v604)
+,	/* CT_v605: (byte 0) */
+  HW(9,3)
+, 0
+,	/* F0_NHC_46FFI_46Prelude_46375_46doRealloc: (byte 0) */
+  CAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46375_46doRealloc),3)
+, VAPTAG(useLabel(FN_LAMBDA571))
+, VAPTAG(useLabel(FN_NHC_46FFI_46_95realloc))
+, VAPTAG(useLabel(FN_Prelude_46fromIntegral))
+, useLabel(CF_Prelude_46Integral_46Prelude_46Int)
+, useLabel(CF_Prelude_46Num_46NHC_46FFI_46CSize)
+, VAPTAG(useLabel(FN_NHC_46FFI_46sizeOf))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
+, VAPTAG(useLabel(FN_NHC_46FFI_46failWhenNULL))
+, bytes2word(0,0,0,0)
+, useLabel(CT_v607)
+,	/* FN_LAMBDA571: (byte 0) */
+  useLabel(TMSUB_NHC_46FFI)
+, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
+, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, CONSTRW(1,0)
+, useLabel(ST_v600)
+, 640022
+, useLabel(ST_v606)
+,	/* CT_v607: (byte 0) */
+  HW(0,0)
+, 0
+,	/* CF_LAMBDA571: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA571))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v552)
+, useLabel(CT_v609)
 ,};
 Node FN_NHC_46FFI_46mallocBytes[] = {
   useLabel(TM_NHC_46FFI)
@@ -366,39 +439,39 @@ Node FN_NHC_46FFI_46mallocBytes[] = {
 , bytes2word(12,HEAP_OFF_N1,5,RETURN_EVAL)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
-, 310001
-, useLabel(ST_v551)
-,	/* CT_v552: (byte 0) */
+, 340001
+, useLabel(ST_v608)
+,	/* CT_v609: (byte 0) */
   HW(7,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46mallocBytes[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46mallocBytes),1)
-, VAPTAG(useLabel(FN_LAMBDA523))
+, VAPTAG(useLabel(FN_LAMBDA572))
 , VAPTAG(useLabel(FN_NHC_46FFI_46_95malloc))
 , VAPTAG(useLabel(FN_Prelude_46fromIntegral))
 , useLabel(CF_Prelude_46Integral_46Prelude_46Int)
-, useLabel(CF_Prelude_46Num_46NHC_46FFI_46CInt)
+, useLabel(CF_Prelude_46Num_46NHC_46FFI_46CSize)
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
 , VAPTAG(useLabel(FN_NHC_46FFI_46failWhenNULL))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v555)
-,	/* FN_LAMBDA523: (byte 0) */
+, useLabel(CT_v612)
+,	/* FN_LAMBDA572: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v554)
-, 310034
-, useLabel(ST_v553)
-,	/* CT_v555: (byte 0) */
+, useLabel(ST_v611)
+, 340034
+, useLabel(ST_v610)
+,	/* CT_v612: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA523: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA523))
+,	/* CF_LAMBDA572: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA572))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v557)
+, useLabel(CT_v614)
 ,};
 Node FN_NHC_46FFI_46allocaBytes[] = {
   useLabel(TM_NHC_46FFI)
@@ -406,9 +479,9 @@ Node FN_NHC_46FFI_46allocaBytes[] = {
 , bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
 , bytes2word(HEAP_CVAL_I5,RETURN,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, 520001
-, useLabel(ST_v556)
-,	/* CT_v557: (byte 0) */
+, 550001
+, useLabel(ST_v613)
+,	/* CT_v614: (byte 0) */
   HW(3,1)
 , 0
 ,};
@@ -418,212 +491,247 @@ Node F0_NHC_46FFI_46allocaBytes[] = {
 , CAPTAG(useLabel(FN_IO_46bracket),1)
 , useLabel(CF_NHC_46FFI_46free)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v559)
+, useLabel(CT_v616)
 ,};
 Node FN_NHC_46FFI_46alloca[] = {
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
 , bytes2word(1,HEAP_CVAL_I4,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, 400001
-, useLabel(ST_v558)
-,	/* CT_v559: (byte 0) */
+, 430001
+, useLabel(ST_v615)
+,	/* CT_v616: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46alloca[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46alloca),1)
-, VAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46362_46doAlloca))
+, VAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46371_46doAlloca))
 , useLabel(CF_Prelude_46undefined)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v561)
-,	/* FN_NHC_46FFI_46Prelude_46362_46doAlloca: (byte 0) */
+, useLabel(CT_v618)
+,	/* FN_NHC_46FFI_46Prelude_46371_46doAlloca: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
 , bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,3,HEAP_ARG)
 , bytes2word(2,PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1)
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, 430005
-, useLabel(ST_v560)
-,	/* CT_v561: (byte 0) */
+, 460005
+, useLabel(ST_v617)
+,	/* CT_v618: (byte 0) */
   HW(3,2)
 , 0
-,	/* F0_NHC_46FFI_46Prelude_46362_46doAlloca: (byte 0) */
-  CAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46362_46doAlloca),2)
+,	/* F0_NHC_46FFI_46Prelude_46371_46doAlloca: (byte 0) */
+  CAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46371_46doAlloca),2)
 , VAPTAG(useLabel(FN_NHC_46FFI_46sizeOf))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
 , VAPTAG(useLabel(FN_NHC_46FFI_46allocaBytes))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v563)
+, useLabel(CT_v620)
 ,};
 Node FN_NHC_46FFI_46malloc[] = {
   useLabel(TM_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
 , bytes2word(1,HEAP_CVAL_I4,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, 230001
-, useLabel(ST_v562)
-,	/* CT_v563: (byte 0) */
+, 260001
+, useLabel(ST_v619)
+,	/* CT_v620: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46malloc[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46malloc),1)
-, VAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46359_46doMalloc))
+, VAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46368_46doMalloc))
 , useLabel(CF_Prelude_46undefined)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v565)
-,	/* FN_NHC_46FFI_46Prelude_46359_46doMalloc: (byte 0) */
+, useLabel(CT_v622)
+,	/* FN_NHC_46FFI_46Prelude_46368_46doMalloc: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
 , bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,3,HEAP_ARG)
 , bytes2word(2,PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1)
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, 260005
-, useLabel(ST_v564)
-,	/* CT_v565: (byte 0) */
+, 290005
+, useLabel(ST_v621)
+,	/* CT_v622: (byte 0) */
   HW(3,2)
 , 0
-,	/* F0_NHC_46FFI_46Prelude_46359_46doMalloc: (byte 0) */
-  CAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46359_46doMalloc),2)
+,	/* F0_NHC_46FFI_46Prelude_46368_46doMalloc: (byte 0) */
+  CAPTAG(useLabel(FN_NHC_46FFI_46Prelude_46368_46doMalloc),2)
 , VAPTAG(useLabel(FN_NHC_46FFI_46sizeOf))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
 , VAPTAG(useLabel(FN_NHC_46FFI_46mallocBytes))
-,	/* ST_v542: (byte 0) */
+,	/* ST_v591: (byte 0) */
   bytes2word(32,111,117,116)
 , bytes2word(32,111,102,32)
 , bytes2word(109,101,109,111)
-,	/* ST_v527: (byte 3) */
+,	/* ST_v576: (byte 3) */
   bytes2word(114,121,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,95)
 , bytes2word(102,114,101,101)
-,	/* ST_v525: (byte 1) */
+,	/* ST_v574: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,95,102,114)
-,	/* ST_v535: (byte 4) */
+,	/* ST_v584: (byte 4) */
   bytes2word(101,101,35,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(95,109,97,108)
-,	/* ST_v533: (byte 4) */
+,	/* ST_v582: (byte 4) */
   bytes2word(108,111,99,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(95,109,97,108)
 , bytes2word(108,111,99,35)
-,	/* ST_v531: (byte 1) */
+,	/* ST_v580: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,95,114,101)
 , bytes2word(97,108,108,111)
-,	/* ST_v529: (byte 2) */
+,	/* ST_v578: (byte 2) */
   bytes2word(99,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,95,114)
 , bytes2word(101,97,108,108)
-,	/* ST_v558: (byte 4) */
+,	/* ST_v615: (byte 4) */
   bytes2word(111,99,35,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(97,108,108,111)
-,	/* ST_v560: (byte 3) */
+,	/* ST_v617: (byte 3) */
   bytes2word(99,97,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,97)
 , bytes2word(108,108,111,99)
-, bytes2word(97,58,52,51)
-,	/* ST_v556: (byte 3) */
-  bytes2word(58,53,0,78)
-, bytes2word(72,67,46,70)
-, bytes2word(70,73,46,97)
-, bytes2word(108,108,111,99)
-, bytes2word(97,66,121,116)
-,	/* ST_v537: (byte 3) */
-  bytes2word(101,115,0,78)
-, bytes2word(72,67,46,70)
-, bytes2word(70,73,46,102)
-, bytes2word(97,105,108,87)
-, bytes2word(104,101,110,78)
-,	/* ST_v539: (byte 4) */
-  bytes2word(85,76,76,0)
+, bytes2word(97,58,52,54)
+, bytes2word(58,53,45,52)
+, bytes2word(54,58,52,55)
+,	/* ST_v613: (byte 1) */
+  bytes2word(0,78,72,67)
+, bytes2word(46,70,70,73)
+, bytes2word(46,97,108,108)
+, bytes2word(111,99,97,66)
+, bytes2word(121,116,101,115)
+,	/* ST_v586: (byte 1) */
+  bytes2word(0,78,72,67)
+, bytes2word(46,70,70,73)
+, bytes2word(46,102,97,105)
+, bytes2word(108,87,104,101)
+, bytes2word(110,78,85,76)
+,	/* ST_v588: (byte 2) */
+  bytes2word(76,0,78,72)
+, bytes2word(67,46,70,70)
+, bytes2word(73,46,102,97)
+, bytes2word(105,108,87,104)
+, bytes2word(101,110,78,85)
+, bytes2word(76,76,58,56)
+, bytes2word(55,58,49,50)
+,	/* ST_v590: (byte 1) */
+  bytes2word(0,78,72,67)
+, bytes2word(46,70,70,73)
+, bytes2word(46,102,97,105)
+, bytes2word(108,87,104,101)
+, bytes2word(110,78,85,76)
+, bytes2word(76,58,56,57)
+, bytes2word(58,50,56,45)
+, bytes2word(56,57,58,52)
+,	/* ST_v593: (byte 2) */
+  bytes2word(51,0,78,72)
+, bytes2word(67,46,70,70)
+, bytes2word(73,46,102,105)
+, bytes2word(110,97,108,105)
+, bytes2word(122,101,114,70)
+,	/* ST_v595: (byte 4) */
+  bytes2word(114,101,101,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
-, bytes2word(102,97,105,108)
-, bytes2word(87,104,101,110)
-, bytes2word(78,85,76,76)
-, bytes2word(58,55,49,58)
-,	/* ST_v541: (byte 3) */
-  bytes2word(49,50,0,78)
-, bytes2word(72,67,46,70)
-, bytes2word(70,73,46,102)
-, bytes2word(97,105,108,87)
-, bytes2word(104,101,110,78)
-, bytes2word(85,76,76,58)
-, bytes2word(55,51,58,50)
-,	/* ST_v544: (byte 2) */
-  bytes2word(56,0,78,72)
-, bytes2word(67,46,70,70)
-, bytes2word(73,46,102,114)
-,	/* ST_v562: (byte 3) */
-  bytes2word(101,101,0,78)
-, bytes2word(72,67,46,70)
-, bytes2word(70,73,46,109)
-, bytes2word(97,108,108,111)
-,	/* ST_v564: (byte 2) */
-  bytes2word(99,0,78,72)
-, bytes2word(67,46,70,70)
-, bytes2word(73,46,109,97)
-, bytes2word(108,108,111,99)
-, bytes2word(58,50,54,58)
-,	/* ST_v551: (byte 2) */
-  bytes2word(53,0,78,72)
+, bytes2word(102,114,101,101)
+,	/* ST_v619: (byte 1) */
+  bytes2word(0,78,72,67)
+, bytes2word(46,70,70,73)
+, bytes2word(46,109,97,108)
+,	/* ST_v621: (byte 4) */
+  bytes2word(108,111,99,0)
+, bytes2word(78,72,67,46)
+, bytes2word(70,70,73,46)
+, bytes2word(109,97,108,108)
+, bytes2word(111,99,58,50)
+, bytes2word(57,58,53,45)
+, bytes2word(50,57,58,52)
+,	/* ST_v608: (byte 2) */
+  bytes2word(55,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,109,97)
 , bytes2word(108,108,111,99)
 , bytes2word(66,121,116,101)
-,	/* ST_v553: (byte 2) */
+,	/* ST_v610: (byte 2) */
   bytes2word(115,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,109,97)
 , bytes2word(108,108,111,99)
 , bytes2word(66,121,116,101)
-, bytes2word(115,58,51,49)
-,	/* ST_v546: (byte 4) */
-  bytes2word(58,51,52,0)
-, bytes2word(78,72,67,46)
-, bytes2word(70,70,73,46)
-, bytes2word(114,101,97,108)
-, bytes2word(108,111,99,66)
-, bytes2word(121,116,101,115)
-,	/* ST_v548: (byte 1) */
+, bytes2word(115,58,51,52)
+, bytes2word(58,51,52,45)
+, bytes2word(51,52,58,52)
+,	/* ST_v602: (byte 2) */
+  bytes2word(49,0,78,72)
+, bytes2word(67,46,70,70)
+, bytes2word(73,46,114,101)
+, bytes2word(97,108,108,111)
+,	/* ST_v604: (byte 2) */
+  bytes2word(99,0,78,72)
+, bytes2word(67,46,70,70)
+, bytes2word(73,46,114,101)
+, bytes2word(97,108,108,111)
+, bytes2word(99,58,54,51)
+, bytes2word(58,53,45,54)
+, bytes2word(52,58,55,50)
+,	/* ST_v606: (byte 1) */
+  bytes2word(0,78,72,67)
+, bytes2word(46,70,70,73)
+, bytes2word(46,114,101,97)
+, bytes2word(108,108,111,99)
+, bytes2word(58,54,52,58)
+, bytes2word(50,50,45,54)
+, bytes2word(52,58,51,48)
+,	/* ST_v597: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,114,101,97)
 , bytes2word(108,108,111,99)
 , bytes2word(66,121,116,101)
-, bytes2word(115,58,53,56)
-,	/* ST_v554: (byte 4) */
-  bytes2word(58,49,54,0)
-, bytes2word(109,97,108,108)
-,	/* ST_v549: (byte 3) */
-  bytes2word(111,99,0,114)
-, bytes2word(101,97,108,108)
-, bytes2word(111,99,0,0)
+,	/* ST_v599: (byte 2) */
+  bytes2word(115,0,78,72)
+, bytes2word(67,46,70,70)
+, bytes2word(73,46,114,101)
+, bytes2word(97,108,108,111)
+, bytes2word(99,66,121,116)
+, bytes2word(101,115,58,55)
+, bytes2word(48,58,49,54)
+, bytes2word(45,55,48,58)
+,	/* ST_v611: (byte 3) */
+  bytes2word(50,52,0,109)
+, bytes2word(97,108,108,111)
+,	/* ST_v600: (byte 2) */
+  bytes2word(99,0,114,101)
+, bytes2word(97,108,108,111)
+, bytes2word(99,0,0,0)
 ,};
 
 #include <haskell2c.h>
 #include <HsFFI.h>
 
-/* foreign import ccall "free" NHC.FFI._free# 1 :: FFI.Ptr -> Prelude.() */
-extern void free(void*);
+/* foreign import ccall "stdlib.h free" NHC.FFI._free# 1 :: FFI.Ptr -> Prelude.() */
+#include "stdlib.h"
 #ifdef PROFILE
-static SInfo pf_free = {"NHC.FFI","NHC.FFI._free#","Prelude.()"};
+static SInfo pf_NHC_46FFI_46_95free_35 = {"NHC.FFI","NHC.FFI._free#","Prelude.()"};
 #endif
 C_HEADER(FR_NHC_46FFI_46_95free_35) {
   NodePtr nodeptr;
@@ -635,14 +743,14 @@ C_HEADER(FR_NHC_46FFI_46_95free_35) {
   free(arg1);
 
   nodeptr = nhc_mkUnit();
-  INIT_PROFINFO(nodeptr,&pf_free);
+  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46_95free_35);
   C_RETURN(nodeptr);
 }
 
-/* foreign import ccall "realloc" NHC.FFI._realloc# 2 :: FFI.Ptr -> Prelude.Int -> FFI.Ptr */
-extern void* realloc(void*,HsInt);
+/* foreign import ccall "stdlib.h realloc" NHC.FFI._realloc# 2 :: FFI.Ptr -> Prelude.Int -> FFI.Ptr */
+#include "stdlib.h"
 #ifdef PROFILE
-static SInfo pf_realloc = {"NHC.FFI","NHC.FFI._realloc#","FFI.Ptr"};
+static SInfo pf_NHC_46FFI_46_95realloc_35 = {"NHC.FFI","NHC.FFI._realloc#","FFI.Ptr"};
 #endif
 C_HEADER(FR_NHC_46FFI_46_95realloc_35) {
   NodePtr nodeptr;
@@ -659,14 +767,14 @@ C_HEADER(FR_NHC_46FFI_46_95realloc_35) {
   result = realloc(arg1,arg2);
 
   nodeptr = nhc_mkInt((int)result);
-  INIT_PROFINFO(nodeptr,&pf_realloc);
+  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46_95realloc_35);
   C_RETURN(nodeptr);
 }
 
-/* foreign import ccall "malloc" NHC.FFI._malloc# 1 :: Prelude.Int -> FFI.Ptr */
-extern void* malloc(HsInt);
+/* foreign import ccall "stdlib.h malloc" NHC.FFI._malloc# 1 :: Prelude.Int -> FFI.Ptr */
+#include "stdlib.h"
 #ifdef PROFILE
-static SInfo pf_malloc = {"NHC.FFI","NHC.FFI._malloc#","FFI.Ptr"};
+static SInfo pf_NHC_46FFI_46_95malloc_35 = {"NHC.FFI","NHC.FFI._malloc#","FFI.Ptr"};
 #endif
 C_HEADER(FR_NHC_46FFI_46_95malloc_35) {
   NodePtr nodeptr;
@@ -679,6 +787,23 @@ C_HEADER(FR_NHC_46FFI_46_95malloc_35) {
   result = malloc(arg1);
 
   nodeptr = nhc_mkInt((int)result);
-  INIT_PROFINFO(nodeptr,&pf_malloc);
+  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46_95malloc_35);
+  C_RETURN(nodeptr);
+}
+
+/* foreign import ccall & "stdlib.h free" NHC.FFI.finalizerFree 0 ::  -> FFI.FunPtr(FFI.Ptr -> Prelude.()) */
+#include "stdlib.h"
+#ifdef PROFILE
+static SInfo pf_NHC_46FFI_46finalizerFree = {"NHC.FFI","NHC.FFI.finalizerFree","FFI.FunPtr(FFI.Ptr -> Prelude.())"};
+#endif
+C_HEADER(FR_NHC_46FFI_46finalizerFree) {
+  NodePtr nodeptr;
+  void(*result)(void*);
+;
+
+  result = (void(*)(void*))&free;
+
+  nodeptr = nhc_mkInt((int)result);
+  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46finalizerFree);
   C_RETURN(nodeptr);
 }
