@@ -1,14 +1,14 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v159	((void*)startLabel+36)
-#define ST_v158	((void*)startLabel+48)
+#define CT_v162	((void*)startLabel+36)
+#define ST_v161	((void*)startLabel+48)
 extern Node TM_Prelude[];
 void FR_Prelude_46primIntegerAbs(void);
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v159)
+, useLabel(CT_v162)
 ,};
 Node FN_Prelude_46primIntegerAbs[] = {
   useLabel(TM_Prelude)
@@ -16,15 +16,15 @@ Node FN_Prelude_46primIntegerAbs[] = {
 , useLabel(FR_Prelude_46primIntegerAbs)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 50040
-, useLabel(ST_v158)
-,	/* CT_v159: (byte 0) */
+, 50001
+, useLabel(ST_v161)
+,	/* CT_v162: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46primIntegerAbs[] = {
   CAPTAG(useLabel(FN_Prelude_46primIntegerAbs),1)
-,	/* ST_v158: (byte 0) */
+,	/* ST_v161: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(112,114,105,109)
@@ -39,7 +39,7 @@ Node F0_Prelude_46primIntegerAbs[] = {
 /* foreign import ccall "primIntegerAbsC" Prelude.primIntegerAbs 1 :: Prelude.Integer -> Prelude.Integer */
 extern NodePtr primIntegerAbsC(NodePtr);
 #ifdef PROFILE
-static SInfo pf_primIntegerAbsC = {"Prelude","Prelude.primIntegerAbs","Prelude.Integer"};
+static SInfo pf_Prelude_46primIntegerAbs = {"Prelude","Prelude.primIntegerAbs","Prelude.Integer"};
 #endif
 C_HEADER(FR_Prelude_46primIntegerAbs) {
   NodePtr nodeptr;
@@ -52,6 +52,6 @@ C_HEADER(FR_Prelude_46primIntegerAbs) {
   result = primIntegerAbsC(arg1);
 
   nodeptr = result;
-  INIT_PROFINFO(nodeptr,&pf_primIntegerAbsC);
+  INIT_PROFINFO(nodeptr,&pf_Prelude_46primIntegerAbs);
   C_RETURN(nodeptr);
 }
