@@ -3,21 +3,19 @@
 #include <setjmp.h>
 
 #include "haskell2c.h"
+#include "initend.h"
 
 /* cExitWith :: ExitCode -> a */
 
-#ifdef __CYGWIN32__
+#if defined(__CYGWIN32__) || defined(__MINGW32__)
 extern jmp_buf exit_mutator;
 #else
 extern sigjmp_buf exit_mutator;
 #endif
-extern int exit_code;
 
 C_HEADER(cExitWith)
 {
   NodePtr nodeptr;
-  char *src;
-  int i;
 
   nodeptr = C_GETARG1(1);
   IND_REMOVE(nodeptr);
@@ -30,7 +28,7 @@ C_HEADER(cExitWith)
     exit_code = GET_INT_VALUE(nodeptr);
     break;
   }
-#ifdef __CYGWIN32__
+#if defined(__CYGWIN32__) || defined(__MINGW32__)
   longjmp(exit_mutator, 1);
 #else
   siglongjmp(exit_mutator,1);
