@@ -2,16 +2,13 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#if !defined(__arm) && !defined(__hppa__) && !defined(__CYGWIN32__)
-#include "localmalloc.h"
-#endif
 #include "node.h"
 /*#include "newmacros.h"  -- already included in node.h */
 /*#include "runtime.h"    -- already included in node.h */
 #include "mark.h"
 
 /*#define HEAPSIZE 100000  -- defined in top-level Makefile at config-time */
-#define STACKSIZE 20000
+#define GCSTACKSIZE 20000
 
 WHEN_DYNAMIC(int ractive = 0;)
 
@@ -22,7 +19,7 @@ NodePtr bitTable;
 
 /* int hpSize = HEAPSIZE;  -- defined at compile-time, and linked in */
 extern int hpSize;
-int spSize = STACKSIZE;
+int spSize = GCSTACKSIZE;
 NodePtr hpStart,hpEnd;
 NodePtr *spStart,*spEnd;
 UserGC *user_gc = NULL;
@@ -61,6 +58,12 @@ void initGc(Int hpSize,NodePtr *ihp,Int spSize,NodePtr **isp)
   *isp = spStart = (NodePtr *) bitTable;
   spEnd = spStart - spSize;
 
+  if ((long)hpEnd>0x80000000) {
+    fprintf(stderr,"OS allocated a heap in high memory (>0x80000000)\n");
+    fprintf(stderr,"    which breaks this program's run-time system.\n");
+    fprintf(stderr,"  hpStart=0x%x, hpEnd=0x%x\n",hpStart,hpEnd);
+    exit(-1);
+  }
   if(spEnd <= (NodePtr*)hpStart) {
     fprintf(stderr,"No space left for the heap!\n");
     exit(-1);
@@ -97,7 +100,7 @@ void initGc(Int hpSize,NodePtr *ihp,Int spSize,NodePtr **isp)
 #if TPROF
   /*hpBase = &hpLowLimit[GCEXTRA];*/
   if(gcData) {
-    fprintf(gdFILE,"HPSP %8d\n",totalSize-tableSize);
+    fprintf(gdFILE,"HPSP %8ld\n",totalSize-tableSize);
   }
 #endif
   *ihp = &hpLowLimit[GCEXTRA];
@@ -124,24 +127,16 @@ void printCaf(GcConst caf, Int flags, Int depth)
     NodePtr *inptr = &cptr->ptr[0];
     switch(GET_TAG(inptr)) {
     case VAP_TAG0: case VAP_TAG1:
-      fprintf(stderr,"%08x * ",inptr);
-#if TRACE
-      prGraph((NodePtr)inptr,flags,depth);
-#else
-      fprintf(stderr," %08x",*inptr);
-#endif
+      fprintf(stderr,"%p * ",inptr);
+      fprintf(stderr," %p",*inptr);
       fprintf(stderr,"\n");
       break;     /* Not updated yet */
     case CON_TAG:
       fprintf(stderr,"CON_TAG in markCaf\n");
       exit(-1);
     case IND_TAG:
-      fprintf(stderr,"%08x   ",inptr);
-#if TRACE
-      prGraph((NodePtr)inptr,flags,depth);
-#else
-      fprintf(stderr," %08x",*inptr);
-#endif
+      fprintf(stderr,"%p   ",inptr);
+      fprintf(stderr," %p",*inptr);
       fprintf(stderr,"\n");
       break;
     }
@@ -191,7 +186,7 @@ void flipCaf(void)
   while(caf != GcEnd) {
     GcConst cptr = caf;
     Int size = cptr->sizeArity;
-    int i,arity = SNDHW(size);
+    int i;
     size = FSTHW(size);
 
     {
@@ -334,13 +329,11 @@ void flipHeap(NodePtr hp)
 void do_profile(NodePtr hp)
 {
   double t = (double)runTime.l/(double)HZ;
-  NodePtr scanptr,newpos;
+  NodePtr scanptr;
   int m;
   int live;
   int dead = post_mortem;
 
-  WHEN_DYNAMIC(extern int FilterRetainer;)
-
   if(pactive && proFILE)
     fprintf(proFILE,"SAMPLE %d %8.2f\n",year,t);
 
@@ -407,15 +400,6 @@ void do_profile(NodePtr hp)
 
 #endif
 
-#if PROFILE
-static void intmove(Int *t,Int *f,int i)
-{
-  while(i--) {
-    *t++ = *f++;
-  }
-}
-#endif
-
 NodePtr moveHeap(NodePtr hp)
 {
   NodePtr scanptr,newpos;
@@ -478,19 +462,14 @@ void do_comment(char *string)
 
 #endif
 
-extern int traceStat, traceShow;
-int tR=0, tAp=0, tNm=0, tInd=0, tRoot=0, tSat=0, tPruned=0;
-int tHidden = 0, tUnknown=0, nPruned = 0;
 
 NodePtr callGc(Int size,NodePtr hp, NodePtr *sp, NodePtr *fp)
 {
-#ifdef DBGTRANS
-  extern int traceK, traceAdaptablePruning;
-/* again:	-- label moved downwards */
-#endif
 
-#if defined(PROFILE) || defined(TPROF)
+#ifdef TPROF
   double thisGcStart;
+#endif
+#if defined(PROFILE) || defined(TPROF)
   NodePtr hpsave = hp;
   int collectinfo =  size<= 0 || (NodePtr)sp >= profileHpLimit; /* called Gc because of profiler */
   pactive = collectinfo;
@@ -505,24 +484,12 @@ NodePtr callGc(Int size,NodePtr hp, NodePtr *sp, NodePtr *fp)
 #endif
 #endif
 
-#ifdef DBGTRANS
-again:
-  ncInit();
-#endif
-
 #ifdef TPROF
   if(!tprof && size) timerStop(&runTime);     /*PH*/
 #else
   if(size) timerStop(&runTime);
 #endif
 
-#if TRACE
-  if(dumpStack && dumpStack <= nogc+1) {
-    fprintf(stderr,"Stack before GC %d\n",nogc+1);
-    prStackGc(sp,fp,traceFlag,traceDepth);
-  }
-#endif
-
 #if PROFILE
   if (proFILE) { /* Add mark to hp-file */
     double t = (double)runTime.l/(double)HZ;
@@ -573,17 +540,6 @@ again:
 
 WHEN_DYNAMIC(if(pactive && ((profile|filter) & PROFILE_RETAINER)) remarkInit();)
 
-#if 0
-/* #ifdef DBGTRANS */
-  {
-      extern int traceK, tracePruneSATs;
-
-      if ((traceK >= 0) || (tracePruneSATs > 0))
-	  tracePrune(sp);
-      
-  }
-#endif
-
   markClear();
 
   if(size) { /* Last call to count cells at program termination */
@@ -608,9 +564,6 @@ WHEN_DYNAMIC(if(pactive && ((profile|filter) & PROFILE_RETAINER)) remarkInit();)
 
     if(dumpStack && dumpStack <= nogc) {
       fprintf(stderr,"CAF before GC %d\n",nogc+1);
-#if TRACE
-      printCaf(oldCaf,traceFlag,1000);
-#endif
     }
 
 WHEN_DYNAMIC(if(pactive && ((profile|filter) & PROFILE_RETAINER)) remarkRest();)
@@ -671,19 +624,9 @@ WHEN_DYNAMIC(if(pactive && ((profile|filter) & PROFILE_RETAINER)) remarkRest();)
     fprintf(stderr,"  Moved %lld words of heap in %d gcs.\n",hpMoved,nogc);
     fprintf(stderr,"  %d words to next gc.",(NodePtr)sp-hp);
     fprintf(stderr,"  Max live after gc: %ld words.\n",hpMaxSurvive);
-#if TRACE
-    hat_exit("Out of heap.",0,-1);
-#endif
     nhc_abort("Insufficient heap memory.");
   }
 
-#if 0
-  if(showGcStack && (nogc >= showGcStackStart)) {
-    fprintf(stderr,"============= leave callGc %d\n",nogc);
-    printStack(sp,fp,0,0,showGcStack,2);
-  }
-
-#endif
   if(bellGc) {
     fflush(stdout);
     fprintf(stderr,"<GC %3d:%8d>\n",nogc,hp-&hpLowLimit[GCEXTRA]);
@@ -737,57 +680,9 @@ WHEN_DYNAMIC(if(pactive && ((profile|filter) & PROFILE_RETAINER)) remarkRest();)
   }
 #endif
 
-#if TRACE
-  if(dumpStack && dumpStack <= nogc) {
-    fprintf(stderr,"Stack after GC %d\n",nogc);
-    prStackGc(sp,fp,traceFlag,traceDepth);
-    fprintf(stderr,"CAF after GC %d\n",nogc);
-    printCaf(oldCaf,traceFlag,1000);
-  }
-#endif
 
   clearCaf();
 
-#if 0 /*TRACE*/
-  {
-    NodePtr t = hp;
-    while (t<(NodePtr)sp)
-      *t++ = 0;
-  }
-#endif
-  
-#ifdef DBGTRANS
-  if (traceStat) {
-      fprintf(stderr, "Gc: R: %d Ap: %d Nm: %d Ind: %d Root: %d Sat: %d Hidden: %d Pruned: %d nPruned: %d\n", tR, tAp, tNm, tInd, tRoot, tSat, tHidden, tPruned, nPruned);
-      tR = tAp = tNm = tInd = tRoot = tSat = tPruned = tHidden = nPruned = 0;
-  }
-
-  if (traceAdaptablePruning) {
-      Int live = hp-&hpLowLimit[GCEXTRA];
-      Int freeheap = (NodePtr)sp-hp;
-      Int percentfree = (freeheap*100)/(live+freeheap);
-
-      if (traceShow) {
-	  fprintf(stderr, "left: %d live: %ld\n", freeheap, live);
-	  fprintf(stderr, "percentage left: %d\n", percentfree);
-	  fprintf(stderr, "k = %d\n", traceK);
-      }
-      if (percentfree < 20) {
-	  if (traceK == 0) {
-	      fprintf(stderr, "Adaptable pruning failed. Program aborted.\n");
-	      exit(1);
-	  }
-	  if (traceK < 0)
-	      traceK = (1 << 6) - 2; /* 6 bits are used, (1 << 6) - 1 is special */
-	  else
-	      traceK = traceK * 3 / 4;
-	  if (traceShow)
-	     fprintf(stderr, "Need to gc again with smaller k (%d)\n", traceK);
-	  goto again;
-      }
-  }
-#endif
-
 #ifdef TPROF
   if(timeSample) tprofRecordGC();	        /*PH*/
   if(!tprof && size) timerStart(&runTime);	/*PH*/
