@@ -11,6 +11,7 @@
 /* #include "bytecode.h" -- already included in node.h via newmacros.h */
 #include "mutlib.h"
 #include "mark.h"
+#include "initend.h"
 
 #if defined(__GNUC__) && !defined(DEBUG)
 #  define USE_GCC_LABELS 1
@@ -41,8 +42,7 @@ static unsigned char penu_instr=EVAL;
 #define register_instr(x)
 #endif
 
-extern int exit_code;
-#ifdef __CYGWIN32__
+#if defined(__CYGWIN32__) || defined(__MINGW32__)
 extern jmp_buf exit_mutator;
 #else
 extern sigjmp_buf exit_mutator;
@@ -72,7 +72,7 @@ int stopInscount;
 static SInfo apply1ProfInfo = { "Runtime","<APPLY>","<APPLY.VAP>"};
 static SInfo apply2ProfInfo = { "Runtime","<APPLY>","<APPLY.$>"};
 static SInfo apply3ProfInfo = { "Runtime","<APPLY>","<APPLY.CAP>"};
-static SInfo evalProfInfo = { "Runtime","<EVAL>","<EVAL.BlackHole>"};
+/* static SInfo evalProfInfo = { "Runtime","<EVAL>","<EVAL.BlackHole>"}; */
 static SInfo int1ProfInfo = { "Runtime","<unary_int_op>","Prelude.Int"};
 static SInfo int2ProfInfo = { "Runtime","<binary_int_op>","Prelude.Int"};
 static SInfo float1ProfInfo = { "Runtime","<unary_float_op>","Prelude.Float"};
@@ -85,15 +85,11 @@ static SInfo string1ProfInfo = { "Runtime","<STRING>","Prelude.Int"};
 static SInfo string2ProfInfo = { "Runtime","<STRING>","<String_VAP>"};
 static SInfo string3ProfInfo = { "Runtime","<STRING>","Prelude.:"};
 static SInfo inpStringProfInfo = { "Runtime","<STRING>","<hGetContents_VAP>"};
-static SInfo handleProfInfo = { "Runtime","<Handle>","IO.Handle"};
+/* static SInfo handleProfInfo = { "Runtime","<Handle>","IO.Handle"}; */
 
 #endif
 
-#if TRACE
-#define DUMP_NODE(n) prGraph(n,0xff,1); fprintf(stderr,"\n");
-#else
-#define DUMP_NODE(n) fprintf(stderr," %08x at %08x\n",n[0],n);
-#endif
+#define DUMP_NODE(n) fprintf(stderr," %08lx at %p\n",n[0],n);
 
 #if PARANOID
 
@@ -125,7 +121,9 @@ static SInfo handleProfInfo = { "Runtime","<Handle>","IO.Handle"};
 
 #if defined(DEBUG)
 #define SHOW(x)	x
+#if USE_GCC_LABELS
 static char *instr_names[];
+#endif
 #else
 #define SHOW(x)
 #endif
@@ -137,7 +135,7 @@ void run(NodePtr toplevel)
   CodePtr ip;			/* -- shadow globals for efficiency */
   NodePtr vapptr;
   NodePtr nodeptr;
-  NodePtr *constptr;
+  NodePtr *constptr = NULL;
 
   TPROF_SETUP
 
@@ -176,23 +174,6 @@ void run(NodePtr toplevel)
   NextInst:
 
 
-#if TRACE
-    if(traceSp&1) prStack(sp,fp,vapptr,constptr,traceFlag,traceDepth);
-    if(traceIp&1) prByteIns(ip);
-
-    inscount++;
-    if(stopInscount && inscount >= stopInscount) {
-      fprintf(stderr,"inscount = %08d\n",inscount);
-    }
-
-    if(ip == stopIP) {
-      fprintf(stderr,"Stop ip = %08x\n",ip);
-    }
-
-    if(hp == stopHP) {
-      fprintf(stderr,"Stop hp = %08x\n",hp);
-    }
-#endif
 #if INSCOUNT
     if(insCount)
       countIns(ip);
@@ -218,15 +199,14 @@ void run(NodePtr toplevel)
 	  ip += HEAPOFFSET(ip[0]) + (HEAPOFFSET(ip[1])<<8);
       } Break;
     Case(NOP):
-      fprintf(stderr,"Executed NOP at %08x\n",ip);
+      fprintf(stderr,"Executed NOP at %p\n",ip);
       Break;
 
     Case(PRIMITIVE):
       { Primitive fun;
-	int gc = 0;
 	ip = (CodePtr) ALIGNPTR(ip);
 	fun = *(Primitive*)ip;
-        SHOW(fprintf(stderr,"\tPRIMITIVE 0x%x\n",(int)fun);)
+        SHOW(fprintf(stderr,"\tPRIMITIVE %p\n",fun);)
         fflush(stderr);
 	ip += sizeof(Primitive);
         TPROF_GREENCARD_ENTER;
@@ -337,24 +317,14 @@ void run(NodePtr toplevel)
 	default:
 	  fprintf(stderr,"Trying to get tag from unevaluated node in UNPACK at %08x!\n",ip-1);
 	  fprintf(stderr,"Node is:\n");
-#if TRACE
-	  prGraph(nodeptr,0xff,1);
-	  fprintf(stderr,"\n");
-#else
 	  fprintf(stderr," %08x at %08x\n",nodeptr[0],nodeptr);
-#endif
 	  exit(-1);
 	  Break; 
 	}
 	if(i!=ip[0]) {
 	  fprintf(stderr,"Trying to do UNPACK %d on a node with %d arguments at %08x!\n",ip[0],i,ip-1);
 	  fprintf(stderr,"Node is:\n");
-#if TRACE
-	  prGraph(nodeptr,0xff,1);
-	  fprintf(stderr,"\n");
-#else
 	  fprintf(stderr," %08x at %08x\n",nodeptr[0],nodeptr);
-#endif
 	  exit(-1);
 	}
       }
@@ -381,16 +351,13 @@ void run(NodePtr toplevel)
 
       cinfo = GET_CINFO(nodeptr);
 
-#ifdef PARANOID
+#if PARANOID
       {
 	  int c = (GET_LARGETAG(nodeptr));
 	  switch(c) {
 	  case CON_DATA | CON_TAG:
 	  case CON_CDATA | CON_TAG:
 	      fprintf(stderr, "Strange: con in apply:\n");
-#if TRACE
-	      prGraph(nodeptr, 3, 3);
-#endif
 	      fprintf(stderr, "\n");
 	      /*startDbg(GET_POINTER_ARG1(nodeptr, 2));*/
 	      exit(-1);
@@ -465,13 +432,6 @@ void run(NodePtr toplevel)
              * an call it; so the result is the same.
              */
 #if 0
-#ifdef DBGTRANS
-            extern void dbg_blackhole();
-	    dbg_blackhole();
-#if 0 /*def PROFILE*/
-	    prGraph(nodeptr, 15, 15);
-#endif
-#else
             extern Node CF_DbgIface_46blackhole[];
             extern Node FN_DbgIface_46fatal[];
 
@@ -495,7 +455,6 @@ void run(NodePtr toplevel)
 	      exit(-1);
 	    }
 	    nodeptr = sp[0];
-#endif
 #endif
 	  }
 	
@@ -504,11 +463,6 @@ void run(NodePtr toplevel)
 	  PUSH_STATE;
 	  vapptr   = nodeptr;
 	  constptr = VAP_CONST(vapptr);
-#if TRACE
-	  if(traceFlag & TRACE_EVAL) {
-	    fprintf(stderr,"<ENTER %s>\n",(char *)constptr[-1]);
-	  }
-#endif
 	  ip       = FINFO_CODE(GET_FINFO(vapptr));
           TPROF_EVAL;
         }
@@ -517,10 +471,6 @@ void run(NodePtr toplevel)
 
  Case(RETURN):
       INSTR("return");
-#if TRACE
-      if(traceFlag & TRACE_RETURN)
-	fprintf(stderr,"<RETURN %s>\n",(char *)constptr[-1]);
-#endif
     nodeptr = *sp++;
     UPDATE_VAP(nodeptr);
     POP_STATEVP;
@@ -528,10 +478,6 @@ void run(NodePtr toplevel)
   Case(RETURN_EVAL):
   return_eval:
       INSTR("returneval");
-#if TRACE
-      if(traceFlag & TRACE_RETURN)
-	fprintf(stderr,"<RETURN(e) %s>\n",(char *)constptr[-1]);
-#endif
     nodeptr = *sp++;
     UPDATE_VAP(nodeptr);
     POP_STATEVP;
@@ -669,6 +615,17 @@ void run(NodePtr toplevel)
   Case(MUL_F): PRIM_OP2_FLOAT(*);
   Case(SLASH_F): PRIM_OP2_FLOAT(/);
 
+  Case(POW_F):
+    { NodePtr nodeptr = *sp++;
+	float a,b;
+	IND_REMOVE(nodeptr); ASSERT_F(ip,nodeptr) UPDATE_PROFINFO(nodeptr) a = get_float_value(nodeptr);
+	nodeptr = *sp++;
+	IND_REMOVE(nodeptr); ASSERT_F(ip,nodeptr) UPDATE_PROFINFO(nodeptr) b = get_float_value(nodeptr);
+	mk_float(hp, (float)pow((double)a,(double)b));
+	INIT_PROFINFO(hp,&float2ProfInfo)
+	*--sp = hp; hp += SIZE_FLOAT;
+    } Break;
+
 #define PRIM_OP1_FLOAT(op) \
     { NodePtr nodeptr = *sp++; \
 	float a;                 \
@@ -725,6 +682,17 @@ void run(NodePtr toplevel)
   Case(MUL_D): PRIM_OP2_DOUBLE(*);
   Case(SLASH_D): PRIM_OP2_DOUBLE(/);
 
+  Case(POW_D):
+    { NodePtr nodeptr = *sp++;
+	double a,b;
+	IND_REMOVE(nodeptr); ASSERT_D(ip,nodeptr) UPDATE_PROFINFO(nodeptr) a = get_double_value(nodeptr);
+	nodeptr = *sp++;
+	IND_REMOVE(nodeptr); ASSERT_D(ip,nodeptr) UPDATE_PROFINFO(nodeptr) b = get_double_value(nodeptr);
+	mk_double(hp, pow(a,b));
+	INIT_PROFINFO(hp,&double2ProfInfo)
+	*--sp = hp; hp += SIZE_DOUBLE;
+    } Break;
+
 #define PRIM_OP1_DOUBLE(op) \
     { NodePtr nodeptr = *sp++; \
 	double a;                 \
@@ -954,7 +922,7 @@ void run(NodePtr toplevel)
               nodeptr = 0;
               break;
           default :
-              fprintf(stderr,"Trying to get tag from unevaluated node in TABLESWITCH at %08x!\n",ip-1);
+              fprintf(stderr,"Trying to get tag from unevaluated node in TABLESWITCH at %p!\n",ip-1);
               fprintf(stderr,"Node is:\n");
               DUMP_NODE(nodeptr);
               exit(-1);
@@ -1042,7 +1010,7 @@ int sizeofNode(Node tag) {
 	return 0;
       }
     }
-  case IND_TAG:
+  default:
     { fprintf(stderr,"IND_TAG in sizeofNode!\n");
       exit(-1);
       return 0;
@@ -1052,7 +1020,7 @@ int sizeofNode(Node tag) {
 
 #endif
 
-#if defined(BYTECODE_PROF) || defined(DEBUG)
+#if defined(BYTECODE_PROF) || (defined(DEBUG) && USE_GCC_LABELS)
 #  undef ins
 static char *instr_names[] = {
  "DUMMY_FOR_ZERO",
@@ -1239,7 +1207,10 @@ static char *instr_names[] = {
  "PUSH_ZAP_ARG_I3",
  "PUSH_ZAP_ARG",
 
- "ENDCODE"
+ "ENDCODE",
+
+ "POW_F",
+ "POW_D"
 };
 #endif
 
